# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DownloadSecurityAssessmentReportDetails(object):
    """
    The details used to download a security assessment report.
    """

    #: A constant which can be used with the format property of a DownloadSecurityAssessmentReportDetails.
    #: This constant has a value of "PDF"
    FORMAT_PDF = "PDF"

    #: A constant which can be used with the format property of a DownloadSecurityAssessmentReportDetails.
    #: This constant has a value of "XLS"
    FORMAT_XLS = "XLS"

    def __init__(self, **kwargs):
        """
        Initializes a new DownloadSecurityAssessmentReportDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param format:
            The value to assign to the format property of this DownloadSecurityAssessmentReportDetails.
            Allowed values for this property are: "PDF", "XLS"
        :type format: str

        """
        self.swagger_types = {
            'format': 'str'
        }

        self.attribute_map = {
            'format': 'format'
        }

        self._format = None

    @property
    def format(self):
        """
        **[Required]** Gets the format of this DownloadSecurityAssessmentReportDetails.
        Format of the report.

        Allowed values for this property are: "PDF", "XLS"


        :return: The format of this DownloadSecurityAssessmentReportDetails.
        :rtype: str
        """
        return self._format

    @format.setter
    def format(self, format):
        """
        Sets the format of this DownloadSecurityAssessmentReportDetails.
        Format of the report.


        :param format: The format of this DownloadSecurityAssessmentReportDetails.
        :type: str
        """
        allowed_values = ["PDF", "XLS"]
        if not value_allowed_none_or_none_sentinel(format, allowed_values):
            raise ValueError(
                "Invalid value for `format`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._format = format

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class MetadataRemap(object):
    """
    Note: Deprecated. Use the new resource model APIs instead.
    Defines remapping to be applied to objects as they are processed.
    Refer to `METADATA_REMAP Procedure `__

    __ https://docs.oracle.com/en/database/oracle/oracle-database/19/arpls/DBMS_DATAPUMP.html#GUID-0FC32790-91E6-4781-87A3-229DE024CB3D
    """

    #: A constant which can be used with the type property of a MetadataRemap.
    #: This constant has a value of "SCHEMA"
    TYPE_SCHEMA = "SCHEMA"

    #: A constant which can be used with the type property of a MetadataRemap.
    #: This constant has a value of "TABLESPACE"
    TYPE_TABLESPACE = "TABLESPACE"

    #: A constant which can be used with the type property of a MetadataRemap.
    #: This constant has a value of "DATAFILE"
    TYPE_DATAFILE = "DATAFILE"

    #: A constant which can be used with the type property of a MetadataRemap.
    #: This constant has a value of "TABLE"
    TYPE_TABLE = "TABLE"

    def __init__(self, **kwargs):
        """
        Initializes a new MetadataRemap object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param type:
            The value to assign to the type property of this MetadataRemap.
            Allowed values for this property are: "SCHEMA", "TABLESPACE", "DATAFILE", "TABLE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type type: str

        :param old_value:
            The value to assign to the old_value property of this MetadataRemap.
        :type old_value: str

        :param new_value:
            The value to assign to the new_value property of this MetadataRemap.
        :type new_value: str

        """
        self.swagger_types = {
            'type': 'str',
            'old_value': 'str',
            'new_value': 'str'
        }

        self.attribute_map = {
            'type': 'type',
            'old_value': 'oldValue',
            'new_value': 'newValue'
        }

        self._type = None
        self._old_value = None
        self._new_value = None

    @property
    def type(self):
        """
        **[Required]** Gets the type of this MetadataRemap.
        Type of remap. Refer to `METADATA_REMAP Procedure `__

        __ https://docs.oracle.com/en/database/oracle/oracle-database/19/arpls/DBMS_DATAPUMP.html#GUID-0FC32790-91E6-4781-87A3-229DE024CB3D

        Allowed values for this property are: "SCHEMA", "TABLESPACE", "DATAFILE", "TABLE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The type of this MetadataRemap.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this MetadataRemap.
        Type of remap. Refer to `METADATA_REMAP Procedure `__

        __ https://docs.oracle.com/en/database/oracle/oracle-database/19/arpls/DBMS_DATAPUMP.html#GUID-0FC32790-91E6-4781-87A3-229DE024CB3D


        :param type: The type of this MetadataRemap.
        :type: str
        """
        allowed_values = ["SCHEMA", "TABLESPACE", "DATAFILE", "TABLE"]
        if not value_allowed_none_or_none_sentinel(type, allowed_values):
            type = 'UNKNOWN_ENUM_VALUE'
        self._type = type

    @property
    def old_value(self):
        """
        **[Required]** Gets the old_value of this MetadataRemap.
        Specifies the value which needs to be reset.


        :return: The old_value of this MetadataRemap.
        :rtype: str
        """
        return self._old_value

    @old_value.setter
    def old_value(self, old_value):
        """
        Sets the old_value of this MetadataRemap.
        Specifies the value which needs to be reset.


        :param old_value: The old_value of this MetadataRemap.
        :type: str
        """
        self._old_value = old_value

    @property
    def new_value(self):
        """
        **[Required]** Gets the new_value of this MetadataRemap.
        Specifies the new value that oldValue should be translated into.


        :return: The new_value of this MetadataRemap.
        :rtype: str
        """
        return self._new_value

    @new_value.setter
    def new_value(self, new_value):
        """
        Sets the new_value of this MetadataRemap.
        Specifies the new value that oldValue should be translated into.


        :param new_value: The new_value of this MetadataRemap.
        :type: str
        """
        self._new_value = new_value

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CostAnalysisUI(object):
    """
    The common fields for Cost Analysis UI rendering.
    """

    #: A constant which can be used with the graph property of a CostAnalysisUI.
    #: This constant has a value of "BARS"
    GRAPH_BARS = "BARS"

    #: A constant which can be used with the graph property of a CostAnalysisUI.
    #: This constant has a value of "LINES"
    GRAPH_LINES = "LINES"

    #: A constant which can be used with the graph property of a CostAnalysisUI.
    #: This constant has a value of "STACKED_LINES"
    GRAPH_STACKED_LINES = "STACKED_LINES"

    def __init__(self, **kwargs):
        """
        Initializes a new CostAnalysisUI object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param graph:
            The value to assign to the graph property of this CostAnalysisUI.
            Allowed values for this property are: "BARS", "LINES", "STACKED_LINES", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type graph: str

        :param is_cumulative_graph:
            The value to assign to the is_cumulative_graph property of this CostAnalysisUI.
        :type is_cumulative_graph: bool

        """
        self.swagger_types = {
            'graph': 'str',
            'is_cumulative_graph': 'bool'
        }

        self.attribute_map = {
            'graph': 'graph',
            'is_cumulative_graph': 'isCumulativeGraph'
        }

        self._graph = None
        self._is_cumulative_graph = None

    @property
    def graph(self):
        """
        Gets the graph of this CostAnalysisUI.
        The graph type.

        Allowed values for this property are: "BARS", "LINES", "STACKED_LINES", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The graph of this CostAnalysisUI.
        :rtype: str
        """
        return self._graph

    @graph.setter
    def graph(self, graph):
        """
        Sets the graph of this CostAnalysisUI.
        The graph type.


        :param graph: The graph of this CostAnalysisUI.
        :type: str
        """
        allowed_values = ["BARS", "LINES", "STACKED_LINES"]
        if not value_allowed_none_or_none_sentinel(graph, allowed_values):
            graph = 'UNKNOWN_ENUM_VALUE'
        self._graph = graph

    @property
    def is_cumulative_graph(self):
        """
        Gets the is_cumulative_graph of this CostAnalysisUI.
        A cumulative graph.


        :return: The is_cumulative_graph of this CostAnalysisUI.
        :rtype: bool
        """
        return self._is_cumulative_graph

    @is_cumulative_graph.setter
    def is_cumulative_graph(self, is_cumulative_graph):
        """
        Sets the is_cumulative_graph of this CostAnalysisUI.
        A cumulative graph.


        :param is_cumulative_graph: The is_cumulative_graph of this CostAnalysisUI.
        :type: bool
        """
        self._is_cumulative_graph = is_cumulative_graph

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CloudExadataInfrastructure(object):
    """
    Details of the cloud Exadata infrastructure resource. Applies to Exadata Cloud Service instances only.
    """

    #: A constant which can be used with the lifecycle_state property of a CloudExadataInfrastructure.
    #: This constant has a value of "PROVISIONING"
    LIFECYCLE_STATE_PROVISIONING = "PROVISIONING"

    #: A constant which can be used with the lifecycle_state property of a CloudExadataInfrastructure.
    #: This constant has a value of "AVAILABLE"
    LIFECYCLE_STATE_AVAILABLE = "AVAILABLE"

    #: A constant which can be used with the lifecycle_state property of a CloudExadataInfrastructure.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    #: A constant which can be used with the lifecycle_state property of a CloudExadataInfrastructure.
    #: This constant has a value of "TERMINATING"
    LIFECYCLE_STATE_TERMINATING = "TERMINATING"

    #: A constant which can be used with the lifecycle_state property of a CloudExadataInfrastructure.
    #: This constant has a value of "TERMINATED"
    LIFECYCLE_STATE_TERMINATED = "TERMINATED"

    #: A constant which can be used with the lifecycle_state property of a CloudExadataInfrastructure.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    #: A constant which can be used with the lifecycle_state property of a CloudExadataInfrastructure.
    #: This constant has a value of "MAINTENANCE_IN_PROGRESS"
    LIFECYCLE_STATE_MAINTENANCE_IN_PROGRESS = "MAINTENANCE_IN_PROGRESS"

    def __init__(self, **kwargs):
        """
        Initializes a new CloudExadataInfrastructure object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this CloudExadataInfrastructure.
        :type id: str

        :param compartment_id:
            The value to assign to the compartment_id property of this CloudExadataInfrastructure.
        :type compartment_id: str

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this CloudExadataInfrastructure.
            Allowed values for this property are: "PROVISIONING", "AVAILABLE", "UPDATING", "TERMINATING", "TERMINATED", "FAILED", "MAINTENANCE_IN_PROGRESS", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param display_name:
            The value to assign to the display_name property of this CloudExadataInfrastructure.
        :type display_name: str

        :param shape:
            The value to assign to the shape property of this CloudExadataInfrastructure.
        :type shape: str

        :param availability_domain:
            The value to assign to the availability_domain property of this CloudExadataInfrastructure.
        :type availability_domain: str

        :param compute_count:
            The value to assign to the compute_count property of this CloudExadataInfrastructure.
        :type compute_count: int

        :param storage_count:
            The value to assign to the storage_count property of this CloudExadataInfrastructure.
        :type storage_count: int

        :param total_storage_size_in_gbs:
            The value to assign to the total_storage_size_in_gbs property of this CloudExadataInfrastructure.
        :type total_storage_size_in_gbs: int

        :param available_storage_size_in_gbs:
            The value to assign to the available_storage_size_in_gbs property of this CloudExadataInfrastructure.
        :type available_storage_size_in_gbs: int

        :param time_created:
            The value to assign to the time_created property of this CloudExadataInfrastructure.
        :type time_created: datetime

        :param lifecycle_details:
            The value to assign to the lifecycle_details property of this CloudExadataInfrastructure.
        :type lifecycle_details: str

        :param maintenance_window:
            The value to assign to the maintenance_window property of this CloudExadataInfrastructure.
        :type maintenance_window: oci.database.models.MaintenanceWindow

        :param last_maintenance_run_id:
            The value to assign to the last_maintenance_run_id property of this CloudExadataInfrastructure.
        :type last_maintenance_run_id: str

        :param next_maintenance_run_id:
            The value to assign to the next_maintenance_run_id property of this CloudExadataInfrastructure.
        :type next_maintenance_run_id: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this CloudExadataInfrastructure.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this CloudExadataInfrastructure.
        :type defined_tags: dict(str, dict(str, object))

        :param customer_contacts:
            The value to assign to the customer_contacts property of this CloudExadataInfrastructure.
        :type customer_contacts: list[oci.database.models.CustomerContact]

        """
        self.swagger_types = {
            'id': 'str',
            'compartment_id': 'str',
            'lifecycle_state': 'str',
            'display_name': 'str',
            'shape': 'str',
            'availability_domain': 'str',
            'compute_count': 'int',
            'storage_count': 'int',
            'total_storage_size_in_gbs': 'int',
            'available_storage_size_in_gbs': 'int',
            'time_created': 'datetime',
            'lifecycle_details': 'str',
            'maintenance_window': 'MaintenanceWindow',
            'last_maintenance_run_id': 'str',
            'next_maintenance_run_id': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'customer_contacts': 'list[CustomerContact]'
        }

        self.attribute_map = {
            'id': 'id',
            'compartment_id': 'compartmentId',
            'lifecycle_state': 'lifecycleState',
            'display_name': 'displayName',
            'shape': 'shape',
            'availability_domain': 'availabilityDomain',
            'compute_count': 'computeCount',
            'storage_count': 'storageCount',
            'total_storage_size_in_gbs': 'totalStorageSizeInGBs',
            'available_storage_size_in_gbs': 'availableStorageSizeInGBs',
            'time_created': 'timeCreated',
            'lifecycle_details': 'lifecycleDetails',
            'maintenance_window': 'maintenanceWindow',
            'last_maintenance_run_id': 'lastMaintenanceRunId',
            'next_maintenance_run_id': 'nextMaintenanceRunId',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'customer_contacts': 'customerContacts'
        }

        self._id = None
        self._compartment_id = None
        self._lifecycle_state = None
        self._display_name = None
        self._shape = None
        self._availability_domain = None
        self._compute_count = None
        self._storage_count = None
        self._total_storage_size_in_gbs = None
        self._available_storage_size_in_gbs = None
        self._time_created = None
        self._lifecycle_details = None
        self._maintenance_window = None
        self._last_maintenance_run_id = None
        self._next_maintenance_run_id = None
        self._freeform_tags = None
        self._defined_tags = None
        self._customer_contacts = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this CloudExadataInfrastructure.
        The `OCID`__ of the cloud Exadata infrastructure resource.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The id of this CloudExadataInfrastructure.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this CloudExadataInfrastructure.
        The `OCID`__ of the cloud Exadata infrastructure resource.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param id: The id of this CloudExadataInfrastructure.
        :type: str
        """
        self._id = id

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this CloudExadataInfrastructure.
        The `OCID`__ of the compartment.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this CloudExadataInfrastructure.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this CloudExadataInfrastructure.
        The `OCID`__ of the compartment.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this CloudExadataInfrastructure.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this CloudExadataInfrastructure.
        The current lifecycle state of the cloud Exadata infrastructure resource.

        Allowed values for this property are: "PROVISIONING", "AVAILABLE", "UPDATING", "TERMINATING", "TERMINATED", "FAILED", "MAINTENANCE_IN_PROGRESS", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this CloudExadataInfrastructure.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this CloudExadataInfrastructure.
        The current lifecycle state of the cloud Exadata infrastructure resource.


        :param lifecycle_state: The lifecycle_state of this CloudExadataInfrastructure.
        :type: str
        """
        allowed_values = ["PROVISIONING", "AVAILABLE", "UPDATING", "TERMINATING", "TERMINATED", "FAILED", "MAINTENANCE_IN_PROGRESS"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this CloudExadataInfrastructure.
        The user-friendly name for the cloud Exadata infrastructure resource. The name does not need to be unique.


        :return: The display_name of this CloudExadataInfrastructure.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this CloudExadataInfrastructure.
        The user-friendly name for the cloud Exadata infrastructure resource. The name does not need to be unique.


        :param display_name: The display_name of this CloudExadataInfrastructure.
        :type: str
        """
        self._display_name = display_name

    @property
    def shape(self):
        """
        **[Required]** Gets the shape of this CloudExadataInfrastructure.
        The model name of the cloud Exadata infrastructure resource.


        :return: The shape of this CloudExadataInfrastructure.
        :rtype: str
        """
        return self._shape

    @shape.setter
    def shape(self, shape):
        """
        Sets the shape of this CloudExadataInfrastructure.
        The model name of the cloud Exadata infrastructure resource.


        :param shape: The shape of this CloudExadataInfrastructure.
        :type: str
        """
        self._shape = shape

    @property
    def availability_domain(self):
        """
        **[Required]** Gets the availability_domain of this CloudExadataInfrastructure.
        The name of the availability domain that the cloud Exadata infrastructure resource is located in.


        :return: The availability_domain of this CloudExadataInfrastructure.
        :rtype: str
        """
        return self._availability_domain

    @availability_domain.setter
    def availability_domain(self, availability_domain):
        """
        Sets the availability_domain of this CloudExadataInfrastructure.
        The name of the availability domain that the cloud Exadata infrastructure resource is located in.


        :param availability_domain: The availability_domain of this CloudExadataInfrastructure.
        :type: str
        """
        self._availability_domain = availability_domain

    @property
    def compute_count(self):
        """
        Gets the compute_count of this CloudExadataInfrastructure.
        The number of compute servers for the cloud Exadata infrastructure.


        :return: The compute_count of this CloudExadataInfrastructure.
        :rtype: int
        """
        return self._compute_count

    @compute_count.setter
    def compute_count(self, compute_count):
        """
        Sets the compute_count of this CloudExadataInfrastructure.
        The number of compute servers for the cloud Exadata infrastructure.


        :param compute_count: The compute_count of this CloudExadataInfrastructure.
        :type: int
        """
        self._compute_count = compute_count

    @property
    def storage_count(self):
        """
        Gets the storage_count of this CloudExadataInfrastructure.
        The number of storage servers for the cloud Exadata infrastructure.


        :return: The storage_count of this CloudExadataInfrastructure.
        :rtype: int
        """
        return self._storage_count

    @storage_count.setter
    def storage_count(self, storage_count):
        """
        Sets the storage_count of this CloudExadataInfrastructure.
        The number of storage servers for the cloud Exadata infrastructure.


        :param storage_count: The storage_count of this CloudExadataInfrastructure.
        :type: int
        """
        self._storage_count = storage_count

    @property
    def total_storage_size_in_gbs(self):
        """
        Gets the total_storage_size_in_gbs of this CloudExadataInfrastructure.
        The total storage allocated to the cloud Exadata infrastructure resource, in gigabytes (GB).


        :return: The total_storage_size_in_gbs of this CloudExadataInfrastructure.
        :rtype: int
        """
        return self._total_storage_size_in_gbs

    @total_storage_size_in_gbs.setter
    def total_storage_size_in_gbs(self, total_storage_size_in_gbs):
        """
        Sets the total_storage_size_in_gbs of this CloudExadataInfrastructure.
        The total storage allocated to the cloud Exadata infrastructure resource, in gigabytes (GB).


        :param total_storage_size_in_gbs: The total_storage_size_in_gbs of this CloudExadataInfrastructure.
        :type: int
        """
        self._total_storage_size_in_gbs = total_storage_size_in_gbs

    @property
    def available_storage_size_in_gbs(self):
        """
        Gets the available_storage_size_in_gbs of this CloudExadataInfrastructure.
        The available storage can be allocated to the cloud Exadata infrastructure resource, in gigabytes (GB).


        :return: The available_storage_size_in_gbs of this CloudExadataInfrastructure.
        :rtype: int
        """
        return self._available_storage_size_in_gbs

    @available_storage_size_in_gbs.setter
    def available_storage_size_in_gbs(self, available_storage_size_in_gbs):
        """
        Sets the available_storage_size_in_gbs of this CloudExadataInfrastructure.
        The available storage can be allocated to the cloud Exadata infrastructure resource, in gigabytes (GB).


        :param available_storage_size_in_gbs: The available_storage_size_in_gbs of this CloudExadataInfrastructure.
        :type: int
        """
        self._available_storage_size_in_gbs = available_storage_size_in_gbs

    @property
    def time_created(self):
        """
        Gets the time_created of this CloudExadataInfrastructure.
        The date and time the cloud Exadata infrastructure resource was created.


        :return: The time_created of this CloudExadataInfrastructure.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this CloudExadataInfrastructure.
        The date and time the cloud Exadata infrastructure resource was created.


        :param time_created: The time_created of this CloudExadataInfrastructure.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def lifecycle_details(self):
        """
        Gets the lifecycle_details of this CloudExadataInfrastructure.
        Additional information about the current lifecycle state.


        :return: The lifecycle_details of this CloudExadataInfrastructure.
        :rtype: str
        """
        return self._lifecycle_details

    @lifecycle_details.setter
    def lifecycle_details(self, lifecycle_details):
        """
        Sets the lifecycle_details of this CloudExadataInfrastructure.
        Additional information about the current lifecycle state.


        :param lifecycle_details: The lifecycle_details of this CloudExadataInfrastructure.
        :type: str
        """
        self._lifecycle_details = lifecycle_details

    @property
    def maintenance_window(self):
        """
        Gets the maintenance_window of this CloudExadataInfrastructure.

        :return: The maintenance_window of this CloudExadataInfrastructure.
        :rtype: oci.database.models.MaintenanceWindow
        """
        return self._maintenance_window

    @maintenance_window.setter
    def maintenance_window(self, maintenance_window):
        """
        Sets the maintenance_window of this CloudExadataInfrastructure.

        :param maintenance_window: The maintenance_window of this CloudExadataInfrastructure.
        :type: oci.database.models.MaintenanceWindow
        """
        self._maintenance_window = maintenance_window

    @property
    def last_maintenance_run_id(self):
        """
        Gets the last_maintenance_run_id of this CloudExadataInfrastructure.
        The `OCID`__ of the last maintenance run.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The last_maintenance_run_id of this CloudExadataInfrastructure.
        :rtype: str
        """
        return self._last_maintenance_run_id

    @last_maintenance_run_id.setter
    def last_maintenance_run_id(self, last_maintenance_run_id):
        """
        Sets the last_maintenance_run_id of this CloudExadataInfrastructure.
        The `OCID`__ of the last maintenance run.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param last_maintenance_run_id: The last_maintenance_run_id of this CloudExadataInfrastructure.
        :type: str
        """
        self._last_maintenance_run_id = last_maintenance_run_id

    @property
    def next_maintenance_run_id(self):
        """
        Gets the next_maintenance_run_id of this CloudExadataInfrastructure.
        The `OCID`__ of the next maintenance run.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The next_maintenance_run_id of this CloudExadataInfrastructure.
        :rtype: str
        """
        return self._next_maintenance_run_id

    @next_maintenance_run_id.setter
    def next_maintenance_run_id(self, next_maintenance_run_id):
        """
        Sets the next_maintenance_run_id of this CloudExadataInfrastructure.
        The `OCID`__ of the next maintenance run.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param next_maintenance_run_id: The next_maintenance_run_id of this CloudExadataInfrastructure.
        :type: str
        """
        self._next_maintenance_run_id = next_maintenance_run_id

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this CloudExadataInfrastructure.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this CloudExadataInfrastructure.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this CloudExadataInfrastructure.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this CloudExadataInfrastructure.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this CloudExadataInfrastructure.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this CloudExadataInfrastructure.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this CloudExadataInfrastructure.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this CloudExadataInfrastructure.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def customer_contacts(self):
        """
        Gets the customer_contacts of this CloudExadataInfrastructure.
        The list of customer email addresses that receive information from Oracle about the specified OCI Database service resource.
        Oracle uses these email addresses to send notifications about planned and unplanned software maintenance updates, information about system hardware, and other information needed by administrators.
        Up to 10 email addresses can be added to the customer contacts for a cloud Exadata infrastructure instance.


        :return: The customer_contacts of this CloudExadataInfrastructure.
        :rtype: list[oci.database.models.CustomerContact]
        """
        return self._customer_contacts

    @customer_contacts.setter
    def customer_contacts(self, customer_contacts):
        """
        Sets the customer_contacts of this CloudExadataInfrastructure.
        The list of customer email addresses that receive information from Oracle about the specified OCI Database service resource.
        Oracle uses these email addresses to send notifications about planned and unplanned software maintenance updates, information about system hardware, and other information needed by administrators.
        Up to 10 email addresses can be added to the customer contacts for a cloud Exadata infrastructure instance.


        :param customer_contacts: The customer_contacts of this CloudExadataInfrastructure.
        :type: list[oci.database.models.CustomerContact]
        """
        self._customer_contacts = customer_contacts

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class SSECustomerKeyDetails(object):
    """
    Specifies the details of the customer-provided encryption key (SSE-C) associated with an object.
    """

    #: A constant which can be used with the algorithm property of a SSECustomerKeyDetails.
    #: This constant has a value of "AES256"
    ALGORITHM_AES256 = "AES256"

    def __init__(self, **kwargs):
        """
        Initializes a new SSECustomerKeyDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param algorithm:
            The value to assign to the algorithm property of this SSECustomerKeyDetails.
            Allowed values for this property are: "AES256"
        :type algorithm: str

        :param key:
            The value to assign to the key property of this SSECustomerKeyDetails.
        :type key: str

        :param key_sha256:
            The value to assign to the key_sha256 property of this SSECustomerKeyDetails.
        :type key_sha256: str

        """
        self.swagger_types = {
            'algorithm': 'str',
            'key': 'str',
            'key_sha256': 'str'
        }

        self.attribute_map = {
            'algorithm': 'algorithm',
            'key': 'key',
            'key_sha256': 'keySha256'
        }

        self._algorithm = None
        self._key = None
        self._key_sha256 = None

    @property
    def algorithm(self):
        """
        **[Required]** Gets the algorithm of this SSECustomerKeyDetails.
        Specifies the encryption algorithm. The only supported value is \"AES256\".

        Allowed values for this property are: "AES256"


        :return: The algorithm of this SSECustomerKeyDetails.
        :rtype: str
        """
        return self._algorithm

    @algorithm.setter
    def algorithm(self, algorithm):
        """
        Sets the algorithm of this SSECustomerKeyDetails.
        Specifies the encryption algorithm. The only supported value is \"AES256\".


        :param algorithm: The algorithm of this SSECustomerKeyDetails.
        :type: str
        """
        allowed_values = ["AES256"]
        if not value_allowed_none_or_none_sentinel(algorithm, allowed_values):
            raise ValueError(
                "Invalid value for `algorithm`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._algorithm = algorithm

    @property
    def key(self):
        """
        **[Required]** Gets the key of this SSECustomerKeyDetails.
        Specifies the base64-encoded 256-bit encryption key to use to encrypt or decrypt the object data.


        :return: The key of this SSECustomerKeyDetails.
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """
        Sets the key of this SSECustomerKeyDetails.
        Specifies the base64-encoded 256-bit encryption key to use to encrypt or decrypt the object data.


        :param key: The key of this SSECustomerKeyDetails.
        :type: str
        """
        self._key = key

    @property
    def key_sha256(self):
        """
        **[Required]** Gets the key_sha256 of this SSECustomerKeyDetails.
        Specifies the base64-encoded SHA256 hash of the encryption key. This value is used to check the integrity
        of the encryption key.


        :return: The key_sha256 of this SSECustomerKeyDetails.
        :rtype: str
        """
        return self._key_sha256

    @key_sha256.setter
    def key_sha256(self, key_sha256):
        """
        Sets the key_sha256 of this SSECustomerKeyDetails.
        Specifies the base64-encoded SHA256 hash of the encryption key. This value is used to check the integrity
        of the encryption key.


        :param key_sha256: The key_sha256 of this SSECustomerKeyDetails.
        :type: str
        """
        self._key_sha256 = key_sha256

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class LaunchEligibility(object):
    """
    Tenant eligibility and other information for launching a PIC image
    """

    def __init__(self, **kwargs):
        """
        Initializes a new LaunchEligibility object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param image_id:
            The value to assign to the image_id property of this LaunchEligibility.
        :type image_id: str

        :param is_launch_allowed:
            The value to assign to the is_launch_allowed property of this LaunchEligibility.
        :type is_launch_allowed: bool

        :param meters:
            The value to assign to the meters property of this LaunchEligibility.
        :type meters: str

        """
        self.swagger_types = {
            'image_id': 'str',
            'is_launch_allowed': 'bool',
            'meters': 'str'
        }

        self.attribute_map = {
            'image_id': 'imageId',
            'is_launch_allowed': 'isLaunchAllowed',
            'meters': 'meters'
        }

        self._image_id = None
        self._is_launch_allowed = None
        self._meters = None

    @property
    def image_id(self):
        """
        **[Required]** Gets the image_id of this LaunchEligibility.
        PIC Image ID


        :return: The image_id of this LaunchEligibility.
        :rtype: str
        """
        return self._image_id

    @image_id.setter
    def image_id(self, image_id):
        """
        Sets the image_id of this LaunchEligibility.
        PIC Image ID


        :param image_id: The image_id of this LaunchEligibility.
        :type: str
        """
        self._image_id = image_id

    @property
    def is_launch_allowed(self):
        """
        **[Required]** Gets the is_launch_allowed of this LaunchEligibility.
        Is the tenant permitted to launch the PIC image


        :return: The is_launch_allowed of this LaunchEligibility.
        :rtype: bool
        """
        return self._is_launch_allowed

    @is_launch_allowed.setter
    def is_launch_allowed(self, is_launch_allowed):
        """
        Sets the is_launch_allowed of this LaunchEligibility.
        Is the tenant permitted to launch the PIC image


        :param is_launch_allowed: The is_launch_allowed of this LaunchEligibility.
        :type: bool
        """
        self._is_launch_allowed = is_launch_allowed

    @property
    def meters(self):
        """
        Gets the meters of this LaunchEligibility.
        related meters for the PIC image


        :return: The meters of this LaunchEligibility.
        :rtype: str
        """
        return self._meters

    @meters.setter
    def meters(self, meters):
        """
        Sets the meters of this LaunchEligibility.
        related meters for the PIC image


        :param meters: The meters of this LaunchEligibility.
        :type: str
        """
        self._meters = meters

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateSshDetails(object):
    """
    Note: Deprecated. Use the new resource model APIs instead.
    Details of the SSH key that will be used.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateSshDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param host:
            The value to assign to the host property of this UpdateSshDetails.
        :type host: str

        :param sshkey:
            The value to assign to the sshkey property of this UpdateSshDetails.
        :type sshkey: str

        :param user:
            The value to assign to the user property of this UpdateSshDetails.
        :type user: str

        :param sudo_location:
            The value to assign to the sudo_location property of this UpdateSshDetails.
        :type sudo_location: str

        """
        self.swagger_types = {
            'host': 'str',
            'sshkey': 'str',
            'user': 'str',
            'sudo_location': 'str'
        }

        self.attribute_map = {
            'host': 'host',
            'sshkey': 'sshkey',
            'user': 'user',
            'sudo_location': 'sudoLocation'
        }

        self._host = None
        self._sshkey = None
        self._user = None
        self._sudo_location = None

    @property
    def host(self):
        """
        Gets the host of this UpdateSshDetails.
        Name of the host the SSH key is valid for.


        :return: The host of this UpdateSshDetails.
        :rtype: str
        """
        return self._host

    @host.setter
    def host(self, host):
        """
        Sets the host of this UpdateSshDetails.
        Name of the host the SSH key is valid for.


        :param host: The host of this UpdateSshDetails.
        :type: str
        """
        self._host = host

    @property
    def sshkey(self):
        """
        Gets the sshkey of this UpdateSshDetails.
        Private SSH key string.


        :return: The sshkey of this UpdateSshDetails.
        :rtype: str
        """
        return self._sshkey

    @sshkey.setter
    def sshkey(self, sshkey):
        """
        Sets the sshkey of this UpdateSshDetails.
        Private SSH key string.


        :param sshkey: The sshkey of this UpdateSshDetails.
        :type: str
        """
        self._sshkey = sshkey

    @property
    def user(self):
        """
        Gets the user of this UpdateSshDetails.
        SSH user


        :return: The user of this UpdateSshDetails.
        :rtype: str
        """
        return self._user

    @user.setter
    def user(self, user):
        """
        Sets the user of this UpdateSshDetails.
        SSH user


        :param user: The user of this UpdateSshDetails.
        :type: str
        """
        self._user = user

    @property
    def sudo_location(self):
        """
        Gets the sudo_location of this UpdateSshDetails.
        Sudo location


        :return: The sudo_location of this UpdateSshDetails.
        :rtype: str
        """
        return self._sudo_location

    @sudo_location.setter
    def sudo_location(self, sudo_location):
        """
        Sets the sudo_location of this UpdateSshDetails.
        Sudo location


        :param sudo_location: The sudo_location of this UpdateSshDetails.
        :type: str
        """
        self._sudo_location = sudo_location

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Modified Work: Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
# Copyright 2008-2016 Andrey Petrov and contributors

from .packages.six.moves.http_client import IncompleteRead as httplib_IncompleteRead

# Base Exceptions


class HTTPError(Exception):
    """Base exception used by this module."""

    pass


class HTTPWarning(Warning):
    """Base warning used by this module."""

    pass


class PoolError(HTTPError):
    """Base exception for errors caused within a pool."""

    def __init__(self, pool, message):
        self.pool = pool
        HTTPError.__init__(self, "%s: %s" % (pool, message))

    def __reduce__(self):
        # For pickling purposes.
        return self.__class__, (None, None)


class RequestError(PoolError):
    """Base exception for PoolErrors that have associated URLs."""

    def __init__(self, pool, url, message):
        self.url = url
        PoolError.__init__(self, pool, message)

    def __reduce__(self):
        # For pickling purposes.
        return self.__class__, (None, self.url, None)


class SSLError(HTTPError):
    """Raised when SSL certificate fails in an HTTPS connection."""

    pass


class ProxyError(HTTPError):
    """Raised when the connection to a proxy fails."""

    def __init__(self, message, error, *args):
        super(ProxyError, self).__init__(message, error, *args)
        self.original_error = error


class DecodeError(HTTPError):
    """Raised when automatic decoding based on Content-Type fails."""

    pass


class ProtocolError(HTTPError):
    """Raised when something unexpected happens mid-request/response."""

    pass


#: Renamed to ProtocolError but aliased for backwards compatibility.
ConnectionError = ProtocolError


# Leaf Exceptions


class MaxRetryError(RequestError):
    """Raised when the maximum number of retries is exceeded.

    :param pool: The connection pool
    :type pool: :class:`~urllib3.connectionpool.HTTPConnectionPool`
    :param string url: The requested Url
    :param exceptions.Exception reason: The underlying error

    """

    def __init__(self, pool, url, reason=None):
        self.reason = reason

        message = "Max retries exceeded with url: %s (Caused by %r)" % (url, reason)

        RequestError.__init__(self, pool, url, message)


class HostChangedError(RequestError):
    """Raised when an existing pool gets a request for a foreign host."""

    def __init__(self, pool, url, retries=3):
        message = "Tried to open a foreign host with url: %s" % url
        RequestError.__init__(self, pool, url, message)
        self.retries = retries


class TimeoutStateError(HTTPError):
    """Raised when passing an invalid state to a timeout"""

    pass


class TimeoutError(HTTPError):
    """Raised when a socket timeout error occurs.

    Catching this error will catch both :exc:`ReadTimeoutErrors
    <ReadTimeoutError>` and :exc:`ConnectTimeoutErrors <ConnectTimeoutError>`.
    """

    pass


class ReadTimeoutError(TimeoutError, RequestError):
    """Raised when a socket timeout occurs while receiving data from a server"""

    pass


# This timeout error does not have a URL attached and needs to inherit from the
# base HTTPError
class ConnectTimeoutError(TimeoutError):
    """Raised when a socket timeout occurs while connecting to a server"""

    pass


class NewConnectionError(ConnectTimeoutError, PoolError):
    """Raised when we fail to establish a new connection. Usually ECONNREFUSED."""

    pass


class EmptyPoolError(PoolError):
    """Raised when a pool runs out of connections and no more are allowed."""

    pass


class ClosedPoolError(PoolError):
    """Raised when a request enters a pool after the pool has been closed."""

    pass


class LocationValueError(ValueError, HTTPError):
    """Raised when there is something wrong with a given URL input."""

    pass


class LocationParseError(LocationValueError):
    """Raised when get_host or similar fails to parse the URL input."""

    def __init__(self, location):
        message = "Failed to parse: %s" % location
        HTTPError.__init__(self, message)

        self.location = location


class URLSchemeUnknown(LocationValueError):
    """Raised when a URL input has an unsupported scheme."""

    def __init__(self, scheme):
        message = "Not supported URL scheme %s" % scheme
        super(URLSchemeUnknown, self).__init__(message)

        self.scheme = scheme


class ResponseError(HTTPError):
    """Used as a container for an error reason supplied in a MaxRetryError."""

    GENERIC_ERROR = "too many error responses"
    SPECIFIC_ERROR = "too many {status_code} error responses"


class SecurityWarning(HTTPWarning):
    """Warned when performing security reducing actions"""

    pass


class SubjectAltNameWarning(SecurityWarning):
    """Warned when connecting to a host with a certificate missing a SAN."""

    pass


class InsecureRequestWarning(SecurityWarning):
    """Warned when making an unverified HTTPS request."""

    pass


class SystemTimeWarning(SecurityWarning):
    """Warned when system time is suspected to be wrong"""

    pass


class InsecurePlatformWarning(SecurityWarning):
    """Warned when certain TLS/SSL configuration is not available on a platform."""

    pass


class SNIMissingWarning(HTTPWarning):
    """Warned when making a HTTPS request without SNI available."""

    pass


class DependencyWarning(HTTPWarning):
    """
    Warned when an attempt is made to import a module with missing optional
    dependencies.
    """

    pass


class ResponseNotChunked(ProtocolError, ValueError):
    """Response needs to be chunked in order to read it as chunks."""

    pass


class BodyNotHttplibCompatible(HTTPError):
    """
    Body should be :class:`http.client.HTTPResponse` like
    (have an fp attribute which returns raw chunks) for read_chunked().
    """

    pass


class IncompleteRead(HTTPError, httplib_IncompleteRead):
    """
    Response length doesn't match expected Content-Length

    Subclass of :class:`http.client.IncompleteRead` to allow int value
    for ``partial`` to avoid creating large objects on streamed reads.
    """

    def __init__(self, partial, expected):
        super(IncompleteRead, self).__init__(partial, expected)

    def __repr__(self):
        return "IncompleteRead(%i bytes read, %i more expected)" % (
            self.partial,
            self.expected,
        )


class InvalidChunkLength(HTTPError, httplib_IncompleteRead):
    """Invalid chunk length in a chunked response."""

    def __init__(self, response, length):
        super(InvalidChunkLength, self).__init__(
            response.tell(), response.length_remaining
        )
        self.response = response
        self.length = length

    def __repr__(self):
        return "InvalidChunkLength(got length %r, %i bytes read)" % (
            self.length,
            self.partial,
        )


class InvalidHeader(HTTPError):
    """The header provided was somehow invalid."""

    pass


class ProxySchemeUnknown(AssertionError, URLSchemeUnknown):
    """ProxyManager does not support the supplied scheme"""

    # TODO(t-8ch): Stop inheriting from AssertionError in v2.0.

    def __init__(self, scheme):
        # 'localhost' is here because our URL parser parses
        # localhost:8080 -> scheme=localhost, remove if we fix this.
        if scheme == "localhost":
            scheme = None
        if scheme is None:
            message = "Proxy URL had no scheme, should start with http:// or https://"
        else:
            message = (
                "Proxy URL had unsupported scheme %s, should use http:// or https://"
                % scheme
            )
        super(ProxySchemeUnknown, self).__init__(message)


class ProxySchemeUnsupported(ValueError):
    """Fetching HTTPS resources through HTTPS proxies is unsupported"""

    pass


class HeaderParsingError(HTTPError):
    """Raised by assert_header_parsing, but we convert it to a log.warning statement."""

    def __init__(self, defects, unparsed_data):
        message = "%s, unparsed data: %r" % (defects or "Unknown", unparsed_data)
        super(HeaderParsingError, self).__init__(message)


class UnrewindableBodyError(HTTPError):
    """urllib3 encountered an error when trying to rewind a body"""

    pass



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class FieldValue(object):
    """
    Field value representing and entry in a list-of-values field.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new FieldValue object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param display_value:
            The value to assign to the display_value property of this FieldValue.
        :type display_value: str

        :param internal_value:
            The value to assign to the internal_value property of this FieldValue.
        :type internal_value: object

        :param is_deleted:
            The value to assign to the is_deleted property of this FieldValue.
        :type is_deleted: bool

        """
        self.swagger_types = {
            'display_value': 'str',
            'internal_value': 'object',
            'is_deleted': 'bool'
        }

        self.attribute_map = {
            'display_value': 'displayValue',
            'internal_value': 'internalValue',
            'is_deleted': 'isDeleted'
        }

        self._display_value = None
        self._internal_value = None
        self._is_deleted = None

    @property
    def display_value(self):
        """
        Gets the display_value of this FieldValue.
        Display representation of the field value.


        :return: The display_value of this FieldValue.
        :rtype: str
        """
        return self._display_value

    @display_value.setter
    def display_value(self, display_value):
        """
        Sets the display_value of this FieldValue.
        Display representation of the field value.


        :param display_value: The display_value of this FieldValue.
        :type: str
        """
        self._display_value = display_value

    @property
    def internal_value(self):
        """
        Gets the internal_value of this FieldValue.
        Internal representation of the field value.


        :return: The internal_value of this FieldValue.
        :rtype: object
        """
        return self._internal_value

    @internal_value.setter
    def internal_value(self, internal_value):
        """
        Sets the internal_value of this FieldValue.
        Internal representation of the field value.


        :param internal_value: The internal_value of this FieldValue.
        :type: object
        """
        self._internal_value = internal_value

    @property
    def is_deleted(self):
        """
        Gets the is_deleted of this FieldValue.
        Denotes if this list-of-values value has been marked as deleted.


        :return: The is_deleted of this FieldValue.
        :rtype: bool
        """
        return self._is_deleted

    @is_deleted.setter
    def is_deleted(self, is_deleted):
        """
        Sets the is_deleted of this FieldValue.
        Denotes if this list-of-values value has been marked as deleted.


        :param is_deleted: The is_deleted of this FieldValue.
        :type: bool
        """
        self._is_deleted = is_deleted

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ChildReference(object):
    """
    Child reference contains application configuration information.
    """

    #: A constant which can be used with the type property of a ChildReference.
    #: This constant has a value of "ORACLEDB_CONNECTION"
    TYPE_ORACLEDB_CONNECTION = "ORACLEDB_CONNECTION"

    #: A constant which can be used with the type property of a ChildReference.
    #: This constant has a value of "ORACLE_OBJECT_STORAGE_CONNECTION"
    TYPE_ORACLE_OBJECT_STORAGE_CONNECTION = "ORACLE_OBJECT_STORAGE_CONNECTION"

    #: A constant which can be used with the type property of a ChildReference.
    #: This constant has a value of "ORACLE_ATP_CONNECTION"
    TYPE_ORACLE_ATP_CONNECTION = "ORACLE_ATP_CONNECTION"

    #: A constant which can be used with the type property of a ChildReference.
    #: This constant has a value of "ORACLE_ADWC_CONNECTION"
    TYPE_ORACLE_ADWC_CONNECTION = "ORACLE_ADWC_CONNECTION"

    #: A constant which can be used with the type property of a ChildReference.
    #: This constant has a value of "MYSQL_CONNECTION"
    TYPE_MYSQL_CONNECTION = "MYSQL_CONNECTION"

    #: A constant which can be used with the type property of a ChildReference.
    #: This constant has a value of "GENERIC_JDBC_CONNECTION"
    TYPE_GENERIC_JDBC_CONNECTION = "GENERIC_JDBC_CONNECTION"

    def __init__(self, **kwargs):
        """
        Initializes a new ChildReference object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param key:
            The value to assign to the key property of this ChildReference.
        :type key: str

        :param name:
            The value to assign to the name property of this ChildReference.
        :type name: str

        :param identifier:
            The value to assign to the identifier property of this ChildReference.
        :type identifier: str

        :param identifier_path:
            The value to assign to the identifier_path property of this ChildReference.
        :type identifier_path: str

        :param description:
            The value to assign to the description property of this ChildReference.
        :type description: str

        :param type:
            The value to assign to the type property of this ChildReference.
            Allowed values for this property are: "ORACLEDB_CONNECTION", "ORACLE_OBJECT_STORAGE_CONNECTION", "ORACLE_ATP_CONNECTION", "ORACLE_ADWC_CONNECTION", "MYSQL_CONNECTION", "GENERIC_JDBC_CONNECTION", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type type: str

        :param target_object:
            The value to assign to the target_object property of this ChildReference.
        :type target_object: object

        :param aggregator_key:
            The value to assign to the aggregator_key property of this ChildReference.
        :type aggregator_key: str

        :param used_by:
            The value to assign to the used_by property of this ChildReference.
        :type used_by: list[oci.data_integration.models.ReferenceUsedBy]

        """
        self.swagger_types = {
            'key': 'str',
            'name': 'str',
            'identifier': 'str',
            'identifier_path': 'str',
            'description': 'str',
            'type': 'str',
            'target_object': 'object',
            'aggregator_key': 'str',
            'used_by': 'list[ReferenceUsedBy]'
        }

        self.attribute_map = {
            'key': 'key',
            'name': 'name',
            'identifier': 'identifier',
            'identifier_path': 'identifierPath',
            'description': 'description',
            'type': 'type',
            'target_object': 'targetObject',
            'aggregator_key': 'aggregatorKey',
            'used_by': 'usedBy'
        }

        self._key = None
        self._name = None
        self._identifier = None
        self._identifier_path = None
        self._description = None
        self._type = None
        self._target_object = None
        self._aggregator_key = None
        self._used_by = None

    @property
    def key(self):
        """
        Gets the key of this ChildReference.
        The reference's key, key of the object that is being used by a published object or its dependents.


        :return: The key of this ChildReference.
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """
        Sets the key of this ChildReference.
        The reference's key, key of the object that is being used by a published object or its dependents.


        :param key: The key of this ChildReference.
        :type: str
        """
        self._key = key

    @property
    def name(self):
        """
        Gets the name of this ChildReference.
        The name of reference object.


        :return: The name of this ChildReference.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ChildReference.
        The name of reference object.


        :param name: The name of this ChildReference.
        :type: str
        """
        self._name = name

    @property
    def identifier(self):
        """
        Gets the identifier of this ChildReference.
        The identifier of reference object.


        :return: The identifier of this ChildReference.
        :rtype: str
        """
        return self._identifier

    @identifier.setter
    def identifier(self, identifier):
        """
        Sets the identifier of this ChildReference.
        The identifier of reference object.


        :param identifier: The identifier of this ChildReference.
        :type: str
        """
        self._identifier = identifier

    @property
    def identifier_path(self):
        """
        Gets the identifier_path of this ChildReference.
        The identifier path of reference object.


        :return: The identifier_path of this ChildReference.
        :rtype: str
        """
        return self._identifier_path

    @identifier_path.setter
    def identifier_path(self, identifier_path):
        """
        Sets the identifier_path of this ChildReference.
        The identifier path of reference object.


        :param identifier_path: The identifier_path of this ChildReference.
        :type: str
        """
        self._identifier_path = identifier_path

    @property
    def description(self):
        """
        Gets the description of this ChildReference.
        The description of reference object.


        :return: The description of this ChildReference.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this ChildReference.
        The description of reference object.


        :param description: The description of this ChildReference.
        :type: str
        """
        self._description = description

    @property
    def type(self):
        """
        Gets the type of this ChildReference.
        The type of the reference object.

        Allowed values for this property are: "ORACLEDB_CONNECTION", "ORACLE_OBJECT_STORAGE_CONNECTION", "ORACLE_ATP_CONNECTION", "ORACLE_ADWC_CONNECTION", "MYSQL_CONNECTION", "GENERIC_JDBC_CONNECTION", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The type of this ChildReference.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this ChildReference.
        The type of the reference object.


        :param type: The type of this ChildReference.
        :type: str
        """
        allowed_values = ["ORACLEDB_CONNECTION", "ORACLE_OBJECT_STORAGE_CONNECTION", "ORACLE_ATP_CONNECTION", "ORACLE_ADWC_CONNECTION", "MYSQL_CONNECTION", "GENERIC_JDBC_CONNECTION"]
        if not value_allowed_none_or_none_sentinel(type, allowed_values):
            type = 'UNKNOWN_ENUM_VALUE'
        self._type = type

    @property
    def target_object(self):
        """
        Gets the target_object of this ChildReference.
        The new reference object to use instead of the original reference. For example, this can be a data asset reference.


        :return: The target_object of this ChildReference.
        :rtype: object
        """
        return self._target_object

    @target_object.setter
    def target_object(self, target_object):
        """
        Sets the target_object of this ChildReference.
        The new reference object to use instead of the original reference. For example, this can be a data asset reference.


        :param target_object: The target_object of this ChildReference.
        :type: object
        """
        self._target_object = target_object

    @property
    def aggregator_key(self):
        """
        Gets the aggregator_key of this ChildReference.
        The aggregator key of the child reference object. For example, this can be a data asset key.


        :return: The aggregator_key of this ChildReference.
        :rtype: str
        """
        return self._aggregator_key

    @aggregator_key.setter
    def aggregator_key(self, aggregator_key):
        """
        Sets the aggregator_key of this ChildReference.
        The aggregator key of the child reference object. For example, this can be a data asset key.


        :param aggregator_key: The aggregator_key of this ChildReference.
        :type: str
        """
        self._aggregator_key = aggregator_key

    @property
    def used_by(self):
        """
        Gets the used_by of this ChildReference.
        List of published objects where this is used.


        :return: The used_by of this ChildReference.
        :rtype: list[oci.data_integration.models.ReferenceUsedBy]
        """
        return self._used_by

    @used_by.setter
    def used_by(self, used_by):
        """
        Sets the used_by of this ChildReference.
        List of published objects where this is used.


        :param used_by: The used_by of this ChildReference.
        :type: list[oci.data_integration.models.ReferenceUsedBy]
        """
        self._used_by = used_by

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class InstanceAgentCommandSummary(object):
    """
    Summary information for a command.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new InstanceAgentCommandSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param instance_agent_command_id:
            The value to assign to the instance_agent_command_id property of this InstanceAgentCommandSummary.
        :type instance_agent_command_id: str

        :param display_name:
            The value to assign to the display_name property of this InstanceAgentCommandSummary.
        :type display_name: str

        :param compartment_id:
            The value to assign to the compartment_id property of this InstanceAgentCommandSummary.
        :type compartment_id: str

        :param time_created:
            The value to assign to the time_created property of this InstanceAgentCommandSummary.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this InstanceAgentCommandSummary.
        :type time_updated: datetime

        :param is_canceled:
            The value to assign to the is_canceled property of this InstanceAgentCommandSummary.
        :type is_canceled: bool

        """
        self.swagger_types = {
            'instance_agent_command_id': 'str',
            'display_name': 'str',
            'compartment_id': 'str',
            'time_created': 'datetime',
            'time_updated': 'datetime',
            'is_canceled': 'bool'
        }

        self.attribute_map = {
            'instance_agent_command_id': 'instanceAgentCommandId',
            'display_name': 'displayName',
            'compartment_id': 'compartmentId',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated',
            'is_canceled': 'isCanceled'
        }

        self._instance_agent_command_id = None
        self._display_name = None
        self._compartment_id = None
        self._time_created = None
        self._time_updated = None
        self._is_canceled = None

    @property
    def instance_agent_command_id(self):
        """
        **[Required]** Gets the instance_agent_command_id of this InstanceAgentCommandSummary.
        The `OCID`__ of the command.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The instance_agent_command_id of this InstanceAgentCommandSummary.
        :rtype: str
        """
        return self._instance_agent_command_id

    @instance_agent_command_id.setter
    def instance_agent_command_id(self, instance_agent_command_id):
        """
        Sets the instance_agent_command_id of this InstanceAgentCommandSummary.
        The `OCID`__ of the command.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param instance_agent_command_id: The instance_agent_command_id of this InstanceAgentCommandSummary.
        :type: str
        """
        self._instance_agent_command_id = instance_agent_command_id

    @property
    def display_name(self):
        """
        Gets the display_name of this InstanceAgentCommandSummary.
        A user-friendly name. Does not have to be unique.


        :return: The display_name of this InstanceAgentCommandSummary.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this InstanceAgentCommandSummary.
        A user-friendly name. Does not have to be unique.


        :param display_name: The display_name of this InstanceAgentCommandSummary.
        :type: str
        """
        self._display_name = display_name

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this InstanceAgentCommandSummary.
        The `OCID`__ of the compartment containing the command.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this InstanceAgentCommandSummary.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this InstanceAgentCommandSummary.
        The `OCID`__ of the compartment containing the command.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this InstanceAgentCommandSummary.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this InstanceAgentCommandSummary.
        The date and time the command was created, in the format defined by
        `RFC3339`__.

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_created of this InstanceAgentCommandSummary.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this InstanceAgentCommandSummary.
        The date and time the command was created, in the format defined by
        `RFC3339`__.

        __ https://tools.ietf.org/html/rfc3339


        :param time_created: The time_created of this InstanceAgentCommandSummary.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_updated(self):
        """
        **[Required]** Gets the time_updated of this InstanceAgentCommandSummary.
        The date and time the command was last updated, in the format defined by
        `RFC3339`__.

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_updated of this InstanceAgentCommandSummary.
        :rtype: datetime
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this InstanceAgentCommandSummary.
        The date and time the command was last updated, in the format defined by
        `RFC3339`__.

        __ https://tools.ietf.org/html/rfc3339


        :param time_updated: The time_updated of this InstanceAgentCommandSummary.
        :type: datetime
        """
        self._time_updated = time_updated

    @property
    def is_canceled(self):
        """
        Gets the is_canceled of this InstanceAgentCommandSummary.
        Whether a request was made to cancel the command. Canceling a command is a best-effort attempt.


        :return: The is_canceled of this InstanceAgentCommandSummary.
        :rtype: bool
        """
        return self._is_canceled

    @is_canceled.setter
    def is_canceled(self, is_canceled):
        """
        Sets the is_canceled of this InstanceAgentCommandSummary.
        Whether a request was made to cancel the command. Canceling a command is a best-effort attempt.


        :param is_canceled: The is_canceled of this InstanceAgentCommandSummary.
        :type: bool
        """
        self._is_canceled = is_canceled

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .detect_anomalies_details import DetectAnomaliesDetails
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class InlineDetectAnomaliesRequest(DetectAnomaliesDetails):
    """
    This is the specialised JSON format that we accept as Training data, with an additional
    field for 'requestType' which is a required field used deciding whether it is an inline
    request or contains embedded data.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new InlineDetectAnomaliesRequest object with values from keyword arguments. The default value of the :py:attr:`~oci.ai_anomaly_detection.models.InlineDetectAnomaliesRequest.request_type` attribute
        of this class is ``INLINE`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param model_id:
            The value to assign to the model_id property of this InlineDetectAnomaliesRequest.
        :type model_id: str

        :param request_type:
            The value to assign to the request_type property of this InlineDetectAnomaliesRequest.
            Allowed values for this property are: "INLINE", "BASE64_ENCODED"
        :type request_type: str

        :param signal_names:
            The value to assign to the signal_names property of this InlineDetectAnomaliesRequest.
        :type signal_names: list[str]

        :param data:
            The value to assign to the data property of this InlineDetectAnomaliesRequest.
        :type data: list[oci.ai_anomaly_detection.models.DataItem]

        """
        self.swagger_types = {
            'model_id': 'str',
            'request_type': 'str',
            'signal_names': 'list[str]',
            'data': 'list[DataItem]'
        }

        self.attribute_map = {
            'model_id': 'modelId',
            'request_type': 'requestType',
            'signal_names': 'signalNames',
            'data': 'data'
        }

        self._model_id = None
        self._request_type = None
        self._signal_names = None
        self._data = None
        self._request_type = 'INLINE'

    @property
    def signal_names(self):
        """
        **[Required]** Gets the signal_names of this InlineDetectAnomaliesRequest.
        List of signal names.


        :return: The signal_names of this InlineDetectAnomaliesRequest.
        :rtype: list[str]
        """
        return self._signal_names

    @signal_names.setter
    def signal_names(self, signal_names):
        """
        Sets the signal_names of this InlineDetectAnomaliesRequest.
        List of signal names.


        :param signal_names: The signal_names of this InlineDetectAnomaliesRequest.
        :type: list[str]
        """
        self._signal_names = signal_names

    @property
    def data(self):
        """
        **[Required]** Gets the data of this InlineDetectAnomaliesRequest.
        Array containing data.


        :return: The data of this InlineDetectAnomaliesRequest.
        :rtype: list[oci.ai_anomaly_detection.models.DataItem]
        """
        return self._data

    @data.setter
    def data(self, data):
        """
        Sets the data of this InlineDetectAnomaliesRequest.
        Array containing data.


        :param data: The data of this InlineDetectAnomaliesRequest.
        :type: list[oci.ai_anomaly_detection.models.DataItem]
        """
        self._data = data

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class LogAnalyticsObjectCollectionRuleSummary(object):
    """
    The summary of an Object Storage based collection rule.
    """

    #: A constant which can be used with the collection_type property of a LogAnalyticsObjectCollectionRuleSummary.
    #: This constant has a value of "LIVE"
    COLLECTION_TYPE_LIVE = "LIVE"

    #: A constant which can be used with the collection_type property of a LogAnalyticsObjectCollectionRuleSummary.
    #: This constant has a value of "HISTORIC"
    COLLECTION_TYPE_HISTORIC = "HISTORIC"

    #: A constant which can be used with the collection_type property of a LogAnalyticsObjectCollectionRuleSummary.
    #: This constant has a value of "HISTORIC_LIVE"
    COLLECTION_TYPE_HISTORIC_LIVE = "HISTORIC_LIVE"

    #: A constant which can be used with the lifecycle_state property of a LogAnalyticsObjectCollectionRuleSummary.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a LogAnalyticsObjectCollectionRuleSummary.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    #: A constant which can be used with the lifecycle_state property of a LogAnalyticsObjectCollectionRuleSummary.
    #: This constant has a value of "INACTIVE"
    LIFECYCLE_STATE_INACTIVE = "INACTIVE"

    def __init__(self, **kwargs):
        """
        Initializes a new LogAnalyticsObjectCollectionRuleSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this LogAnalyticsObjectCollectionRuleSummary.
        :type id: str

        :param name:
            The value to assign to the name property of this LogAnalyticsObjectCollectionRuleSummary.
        :type name: str

        :param description:
            The value to assign to the description property of this LogAnalyticsObjectCollectionRuleSummary.
        :type description: str

        :param compartment_id:
            The value to assign to the compartment_id property of this LogAnalyticsObjectCollectionRuleSummary.
        :type compartment_id: str

        :param os_namespace:
            The value to assign to the os_namespace property of this LogAnalyticsObjectCollectionRuleSummary.
        :type os_namespace: str

        :param os_bucket_name:
            The value to assign to the os_bucket_name property of this LogAnalyticsObjectCollectionRuleSummary.
        :type os_bucket_name: str

        :param collection_type:
            The value to assign to the collection_type property of this LogAnalyticsObjectCollectionRuleSummary.
            Allowed values for this property are: "LIVE", "HISTORIC", "HISTORIC_LIVE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type collection_type: str

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this LogAnalyticsObjectCollectionRuleSummary.
            Allowed values for this property are: "ACTIVE", "DELETED", "INACTIVE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param lifecycle_details:
            The value to assign to the lifecycle_details property of this LogAnalyticsObjectCollectionRuleSummary.
        :type lifecycle_details: str

        :param time_created:
            The value to assign to the time_created property of this LogAnalyticsObjectCollectionRuleSummary.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this LogAnalyticsObjectCollectionRuleSummary.
        :type time_updated: datetime

        :param is_enabled:
            The value to assign to the is_enabled property of this LogAnalyticsObjectCollectionRuleSummary.
        :type is_enabled: bool

        :param defined_tags:
            The value to assign to the defined_tags property of this LogAnalyticsObjectCollectionRuleSummary.
        :type defined_tags: dict(str, dict(str, object))

        :param freeform_tags:
            The value to assign to the freeform_tags property of this LogAnalyticsObjectCollectionRuleSummary.
        :type freeform_tags: dict(str, str)

        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'description': 'str',
            'compartment_id': 'str',
            'os_namespace': 'str',
            'os_bucket_name': 'str',
            'collection_type': 'str',
            'lifecycle_state': 'str',
            'lifecycle_details': 'str',
            'time_created': 'datetime',
            'time_updated': 'datetime',
            'is_enabled': 'bool',
            'defined_tags': 'dict(str, dict(str, object))',
            'freeform_tags': 'dict(str, str)'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'description': 'description',
            'compartment_id': 'compartmentId',
            'os_namespace': 'osNamespace',
            'os_bucket_name': 'osBucketName',
            'collection_type': 'collectionType',
            'lifecycle_state': 'lifecycleState',
            'lifecycle_details': 'lifecycleDetails',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated',
            'is_enabled': 'isEnabled',
            'defined_tags': 'definedTags',
            'freeform_tags': 'freeformTags'
        }

        self._id = None
        self._name = None
        self._description = None
        self._compartment_id = None
        self._os_namespace = None
        self._os_bucket_name = None
        self._collection_type = None
        self._lifecycle_state = None
        self._lifecycle_details = None
        self._time_created = None
        self._time_updated = None
        self._is_enabled = None
        self._defined_tags = None
        self._freeform_tags = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this LogAnalyticsObjectCollectionRuleSummary.
        The `OCID`__ of this rule.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The id of this LogAnalyticsObjectCollectionRuleSummary.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this LogAnalyticsObjectCollectionRuleSummary.
        The `OCID`__ of this rule.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param id: The id of this LogAnalyticsObjectCollectionRuleSummary.
        :type: str
        """
        self._id = id

    @property
    def name(self):
        """
        **[Required]** Gets the name of this LogAnalyticsObjectCollectionRuleSummary.
        A unique name to the rule. The name must be unique, within the tenancy, and cannot be changed.


        :return: The name of this LogAnalyticsObjectCollectionRuleSummary.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this LogAnalyticsObjectCollectionRuleSummary.
        A unique name to the rule. The name must be unique, within the tenancy, and cannot be changed.


        :param name: The name of this LogAnalyticsObjectCollectionRuleSummary.
        :type: str
        """
        self._name = name

    @property
    def description(self):
        """
        Gets the description of this LogAnalyticsObjectCollectionRuleSummary.
        A unique name given to the rule. The name must be unique within the tenancy, and cannot be modified.
        Avoid entering confidential information.


        :return: The description of this LogAnalyticsObjectCollectionRuleSummary.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this LogAnalyticsObjectCollectionRuleSummary.
        A unique name given to the rule. The name must be unique within the tenancy, and cannot be modified.
        Avoid entering confidential information.


        :param description: The description of this LogAnalyticsObjectCollectionRuleSummary.
        :type: str
        """
        self._description = description

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this LogAnalyticsObjectCollectionRuleSummary.
        The `OCID`__ of the compartment to which this rule belongs.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this LogAnalyticsObjectCollectionRuleSummary.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this LogAnalyticsObjectCollectionRuleSummary.
        The `OCID`__ of the compartment to which this rule belongs.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this LogAnalyticsObjectCollectionRuleSummary.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def os_namespace(self):
        """
        **[Required]** Gets the os_namespace of this LogAnalyticsObjectCollectionRuleSummary.
        Object Storage namespace.


        :return: The os_namespace of this LogAnalyticsObjectCollectionRuleSummary.
        :rtype: str
        """
        return self._os_namespace

    @os_namespace.setter
    def os_namespace(self, os_namespace):
        """
        Sets the os_namespace of this LogAnalyticsObjectCollectionRuleSummary.
        Object Storage namespace.


        :param os_namespace: The os_namespace of this LogAnalyticsObjectCollectionRuleSummary.
        :type: str
        """
        self._os_namespace = os_namespace

    @property
    def os_bucket_name(self):
        """
        **[Required]** Gets the os_bucket_name of this LogAnalyticsObjectCollectionRuleSummary.
        Name of the Object Storage bucket.


        :return: The os_bucket_name of this LogAnalyticsObjectCollectionRuleSummary.
        :rtype: str
        """
        return self._os_bucket_name

    @os_bucket_name.setter
    def os_bucket_name(self, os_bucket_name):
        """
        Sets the os_bucket_name of this LogAnalyticsObjectCollectionRuleSummary.
        Name of the Object Storage bucket.


        :param os_bucket_name: The os_bucket_name of this LogAnalyticsObjectCollectionRuleSummary.
        :type: str
        """
        self._os_bucket_name = os_bucket_name

    @property
    def collection_type(self):
        """
        **[Required]** Gets the collection_type of this LogAnalyticsObjectCollectionRuleSummary.
        The type of log collection.

        Allowed values for this property are: "LIVE", "HISTORIC", "HISTORIC_LIVE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The collection_type of this LogAnalyticsObjectCollectionRuleSummary.
        :rtype: str
        """
        return self._collection_type

    @collection_type.setter
    def collection_type(self, collection_type):
        """
        Sets the collection_type of this LogAnalyticsObjectCollectionRuleSummary.
        The type of log collection.


        :param collection_type: The collection_type of this LogAnalyticsObjectCollectionRuleSummary.
        :type: str
        """
        allowed_values = ["LIVE", "HISTORIC", "HISTORIC_LIVE"]
        if not value_allowed_none_or_none_sentinel(collection_type, allowed_values):
            collection_type = 'UNKNOWN_ENUM_VALUE'
        self._collection_type = collection_type

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this LogAnalyticsObjectCollectionRuleSummary.
        The current state of the rule.

        Allowed values for this property are: "ACTIVE", "DELETED", "INACTIVE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this LogAnalyticsObjectCollectionRuleSummary.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this LogAnalyticsObjectCollectionRuleSummary.
        The current state of the rule.


        :param lifecycle_state: The lifecycle_state of this LogAnalyticsObjectCollectionRuleSummary.
        :type: str
        """
        allowed_values = ["ACTIVE", "DELETED", "INACTIVE"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def lifecycle_details(self):
        """
        Gets the lifecycle_details of this LogAnalyticsObjectCollectionRuleSummary.
        A detailed status of the life cycle state.


        :return: The lifecycle_details of this LogAnalyticsObjectCollectionRuleSummary.
        :rtype: str
        """
        return self._lifecycle_details

    @lifecycle_details.setter
    def lifecycle_details(self, lifecycle_details):
        """
        Sets the lifecycle_details of this LogAnalyticsObjectCollectionRuleSummary.
        A detailed status of the life cycle state.


        :param lifecycle_details: The lifecycle_details of this LogAnalyticsObjectCollectionRuleSummary.
        :type: str
        """
        self._lifecycle_details = lifecycle_details

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this LogAnalyticsObjectCollectionRuleSummary.
        The time when this rule was created. An RFC3339 formatted datetime string.


        :return: The time_created of this LogAnalyticsObjectCollectionRuleSummary.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this LogAnalyticsObjectCollectionRuleSummary.
        The time when this rule was created. An RFC3339 formatted datetime string.


        :param time_created: The time_created of this LogAnalyticsObjectCollectionRuleSummary.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_updated(self):
        """
        **[Required]** Gets the time_updated of this LogAnalyticsObjectCollectionRuleSummary.
        The time when this rule was last updated. An RFC3339 formatted datetime string.


        :return: The time_updated of this LogAnalyticsObjectCollectionRuleSummary.
        :rtype: datetime
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this LogAnalyticsObjectCollectionRuleSummary.
        The time when this rule was last updated. An RFC3339 formatted datetime string.


        :param time_updated: The time_updated of this LogAnalyticsObjectCollectionRuleSummary.
        :type: datetime
        """
        self._time_updated = time_updated

    @property
    def is_enabled(self):
        """
        **[Required]** Gets the is_enabled of this LogAnalyticsObjectCollectionRuleSummary.
        Whether or not this rule is currently enabled.


        :return: The is_enabled of this LogAnalyticsObjectCollectionRuleSummary.
        :rtype: bool
        """
        return self._is_enabled

    @is_enabled.setter
    def is_enabled(self, is_enabled):
        """
        Sets the is_enabled of this LogAnalyticsObjectCollectionRuleSummary.
        Whether or not this rule is currently enabled.


        :param is_enabled: The is_enabled of this LogAnalyticsObjectCollectionRuleSummary.
        :type: bool
        """
        self._is_enabled = is_enabled

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this LogAnalyticsObjectCollectionRuleSummary.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :return: The defined_tags of this LogAnalyticsObjectCollectionRuleSummary.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this LogAnalyticsObjectCollectionRuleSummary.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :param defined_tags: The defined_tags of this LogAnalyticsObjectCollectionRuleSummary.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this LogAnalyticsObjectCollectionRuleSummary.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :return: The freeform_tags of this LogAnalyticsObjectCollectionRuleSummary.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this LogAnalyticsObjectCollectionRuleSummary.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :param freeform_tags: The freeform_tags of this LogAnalyticsObjectCollectionRuleSummary.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class LogAnalyticsEmBridgeSummaryReport(object):
    """
    Log-Analytics EM Bridge counts summary.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new LogAnalyticsEmBridgeSummaryReport object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param compartment_id:
            The value to assign to the compartment_id property of this LogAnalyticsEmBridgeSummaryReport.
        :type compartment_id: str

        :param active_em_bridge_count:
            The value to assign to the active_em_bridge_count property of this LogAnalyticsEmBridgeSummaryReport.
        :type active_em_bridge_count: int

        :param creating_em_bridge_count:
            The value to assign to the creating_em_bridge_count property of this LogAnalyticsEmBridgeSummaryReport.
        :type creating_em_bridge_count: int

        :param needs_attention_em_bridge_count:
            The value to assign to the needs_attention_em_bridge_count property of this LogAnalyticsEmBridgeSummaryReport.
        :type needs_attention_em_bridge_count: int

        :param deleted_em_bridge_count:
            The value to assign to the deleted_em_bridge_count property of this LogAnalyticsEmBridgeSummaryReport.
        :type deleted_em_bridge_count: int

        :param total_em_bridge_count:
            The value to assign to the total_em_bridge_count property of this LogAnalyticsEmBridgeSummaryReport.
        :type total_em_bridge_count: int

        """
        self.swagger_types = {
            'compartment_id': 'str',
            'active_em_bridge_count': 'int',
            'creating_em_bridge_count': 'int',
            'needs_attention_em_bridge_count': 'int',
            'deleted_em_bridge_count': 'int',
            'total_em_bridge_count': 'int'
        }

        self.attribute_map = {
            'compartment_id': 'compartmentId',
            'active_em_bridge_count': 'activeEmBridgeCount',
            'creating_em_bridge_count': 'creatingEmBridgeCount',
            'needs_attention_em_bridge_count': 'needsAttentionEmBridgeCount',
            'deleted_em_bridge_count': 'deletedEmBridgeCount',
            'total_em_bridge_count': 'totalEmBridgeCount'
        }

        self._compartment_id = None
        self._active_em_bridge_count = None
        self._creating_em_bridge_count = None
        self._needs_attention_em_bridge_count = None
        self._deleted_em_bridge_count = None
        self._total_em_bridge_count = None

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this LogAnalyticsEmBridgeSummaryReport.
        Compartment Identifier `OCID]`__.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this LogAnalyticsEmBridgeSummaryReport.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this LogAnalyticsEmBridgeSummaryReport.
        Compartment Identifier `OCID]`__.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this LogAnalyticsEmBridgeSummaryReport.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def active_em_bridge_count(self):
        """
        **[Required]** Gets the active_em_bridge_count of this LogAnalyticsEmBridgeSummaryReport.
        Total number of ACTIVE enterprise manager bridges.


        :return: The active_em_bridge_count of this LogAnalyticsEmBridgeSummaryReport.
        :rtype: int
        """
        return self._active_em_bridge_count

    @active_em_bridge_count.setter
    def active_em_bridge_count(self, active_em_bridge_count):
        """
        Sets the active_em_bridge_count of this LogAnalyticsEmBridgeSummaryReport.
        Total number of ACTIVE enterprise manager bridges.


        :param active_em_bridge_count: The active_em_bridge_count of this LogAnalyticsEmBridgeSummaryReport.
        :type: int
        """
        self._active_em_bridge_count = active_em_bridge_count

    @property
    def creating_em_bridge_count(self):
        """
        **[Required]** Gets the creating_em_bridge_count of this LogAnalyticsEmBridgeSummaryReport.
        Number of enterprise manager bridges in CREATING state.


        :return: The creating_em_bridge_count of this LogAnalyticsEmBridgeSummaryReport.
        :rtype: int
        """
        return self._creating_em_bridge_count

    @creating_em_bridge_count.setter
    def creating_em_bridge_count(self, creating_em_bridge_count):
        """
        Sets the creating_em_bridge_count of this LogAnalyticsEmBridgeSummaryReport.
        Number of enterprise manager bridges in CREATING state.


        :param creating_em_bridge_count: The creating_em_bridge_count of this LogAnalyticsEmBridgeSummaryReport.
        :type: int
        """
        self._creating_em_bridge_count = creating_em_bridge_count

    @property
    def needs_attention_em_bridge_count(self):
        """
        **[Required]** Gets the needs_attention_em_bridge_count of this LogAnalyticsEmBridgeSummaryReport.
        Number of enterprise manager bridges in NEEDS_ATTENTION state.


        :return: The needs_attention_em_bridge_count of this LogAnalyticsEmBridgeSummaryReport.
        :rtype: int
        """
        return self._needs_attention_em_bridge_count

    @needs_attention_em_bridge_count.setter
    def needs_attention_em_bridge_count(self, needs_attention_em_bridge_count):
        """
        Sets the needs_attention_em_bridge_count of this LogAnalyticsEmBridgeSummaryReport.
        Number of enterprise manager bridges in NEEDS_ATTENTION state.


        :param needs_attention_em_bridge_count: The needs_attention_em_bridge_count of this LogAnalyticsEmBridgeSummaryReport.
        :type: int
        """
        self._needs_attention_em_bridge_count = needs_attention_em_bridge_count

    @property
    def deleted_em_bridge_count(self):
        """
        **[Required]** Gets the deleted_em_bridge_count of this LogAnalyticsEmBridgeSummaryReport.
        Number of enterprise manager bridges in DELETED state.


        :return: The deleted_em_bridge_count of this LogAnalyticsEmBridgeSummaryReport.
        :rtype: int
        """
        return self._deleted_em_bridge_count

    @deleted_em_bridge_count.setter
    def deleted_em_bridge_count(self, deleted_em_bridge_count):
        """
        Sets the deleted_em_bridge_count of this LogAnalyticsEmBridgeSummaryReport.
        Number of enterprise manager bridges in DELETED state.


        :param deleted_em_bridge_count: The deleted_em_bridge_count of this LogAnalyticsEmBridgeSummaryReport.
        :type: int
        """
        self._deleted_em_bridge_count = deleted_em_bridge_count

    @property
    def total_em_bridge_count(self):
        """
        **[Required]** Gets the total_em_bridge_count of this LogAnalyticsEmBridgeSummaryReport.
        Total number of enterprise manager bridges.


        :return: The total_em_bridge_count of this LogAnalyticsEmBridgeSummaryReport.
        :rtype: int
        """
        return self._total_em_bridge_count

    @total_em_bridge_count.setter
    def total_em_bridge_count(self, total_em_bridge_count):
        """
        Sets the total_em_bridge_count of this LogAnalyticsEmBridgeSummaryReport.
        Total number of enterprise manager bridges.


        :param total_em_bridge_count: The total_em_bridge_count of this LogAnalyticsEmBridgeSummaryReport.
        :type: int
        """
        self._total_em_bridge_count = total_em_bridge_count

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ConnectionProperty(object):
    """
    The connection name/value pair.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ConnectionProperty object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this ConnectionProperty.
        :type name: str

        :param value:
            The value to assign to the value property of this ConnectionProperty.
        :type value: str

        """
        self.swagger_types = {
            'name': 'str',
            'value': 'str'
        }

        self.attribute_map = {
            'name': 'name',
            'value': 'value'
        }

        self._name = None
        self._value = None

    @property
    def name(self):
        """
        Gets the name of this ConnectionProperty.
        Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.


        :return: The name of this ConnectionProperty.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ConnectionProperty.
        Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.


        :param name: The name of this ConnectionProperty.
        :type: str
        """
        self._name = name

    @property
    def value(self):
        """
        Gets the value of this ConnectionProperty.
        The value for the connection name property.


        :return: The value of this ConnectionProperty.
        :rtype: str
        """
        return self._value

    @value.setter
    def value(self, value):
        """
        Sets the value of this ConnectionProperty.
        The value for the connection name property.


        :param value: The value of this ConnectionProperty.
        :type: str
        """
        self._value = value

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Rule(object):
    """
    An object that represents an action to apply to a listener.
    """

    #: A constant which can be used with the action property of a Rule.
    #: This constant has a value of "ADD_HTTP_REQUEST_HEADER"
    ACTION_ADD_HTTP_REQUEST_HEADER = "ADD_HTTP_REQUEST_HEADER"

    #: A constant which can be used with the action property of a Rule.
    #: This constant has a value of "EXTEND_HTTP_REQUEST_HEADER_VALUE"
    ACTION_EXTEND_HTTP_REQUEST_HEADER_VALUE = "EXTEND_HTTP_REQUEST_HEADER_VALUE"

    #: A constant which can be used with the action property of a Rule.
    #: This constant has a value of "REMOVE_HTTP_REQUEST_HEADER"
    ACTION_REMOVE_HTTP_REQUEST_HEADER = "REMOVE_HTTP_REQUEST_HEADER"

    #: A constant which can be used with the action property of a Rule.
    #: This constant has a value of "ADD_HTTP_RESPONSE_HEADER"
    ACTION_ADD_HTTP_RESPONSE_HEADER = "ADD_HTTP_RESPONSE_HEADER"

    #: A constant which can be used with the action property of a Rule.
    #: This constant has a value of "EXTEND_HTTP_RESPONSE_HEADER_VALUE"
    ACTION_EXTEND_HTTP_RESPONSE_HEADER_VALUE = "EXTEND_HTTP_RESPONSE_HEADER_VALUE"

    #: A constant which can be used with the action property of a Rule.
    #: This constant has a value of "REMOVE_HTTP_RESPONSE_HEADER"
    ACTION_REMOVE_HTTP_RESPONSE_HEADER = "REMOVE_HTTP_RESPONSE_HEADER"

    #: A constant which can be used with the action property of a Rule.
    #: This constant has a value of "ALLOW"
    ACTION_ALLOW = "ALLOW"

    #: A constant which can be used with the action property of a Rule.
    #: This constant has a value of "CONTROL_ACCESS_USING_HTTP_METHODS"
    ACTION_CONTROL_ACCESS_USING_HTTP_METHODS = "CONTROL_ACCESS_USING_HTTP_METHODS"

    #: A constant which can be used with the action property of a Rule.
    #: This constant has a value of "REDIRECT"
    ACTION_REDIRECT = "REDIRECT"

    #: A constant which can be used with the action property of a Rule.
    #: This constant has a value of "HTTP_HEADER"
    ACTION_HTTP_HEADER = "HTTP_HEADER"

    def __init__(self, **kwargs):
        """
        Initializes a new Rule object with values from keyword arguments. This class has the following subclasses and if you are using this class as input
        to a service operations then you should favor using a subclass over the base class:

        * :class:`~oci.load_balancer.models.AddHttpRequestHeaderRule`
        * :class:`~oci.load_balancer.models.RedirectRule`
        * :class:`~oci.load_balancer.models.RemoveHttpRequestHeaderRule`
        * :class:`~oci.load_balancer.models.ExtendHttpRequestHeaderValueRule`
        * :class:`~oci.load_balancer.models.RemoveHttpResponseHeaderRule`
        * :class:`~oci.load_balancer.models.ControlAccessUsingHttpMethodsRule`
        * :class:`~oci.load_balancer.models.AllowRule`
        * :class:`~oci.load_balancer.models.HttpHeaderRule`
        * :class:`~oci.load_balancer.models.AddHttpResponseHeaderRule`
        * :class:`~oci.load_balancer.models.ExtendHttpResponseHeaderValueRule`

        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param action:
            The value to assign to the action property of this Rule.
            Allowed values for this property are: "ADD_HTTP_REQUEST_HEADER", "EXTEND_HTTP_REQUEST_HEADER_VALUE", "REMOVE_HTTP_REQUEST_HEADER", "ADD_HTTP_RESPONSE_HEADER", "EXTEND_HTTP_RESPONSE_HEADER_VALUE", "REMOVE_HTTP_RESPONSE_HEADER", "ALLOW", "CONTROL_ACCESS_USING_HTTP_METHODS", "REDIRECT", "HTTP_HEADER", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type action: str

        """
        self.swagger_types = {
            'action': 'str'
        }

        self.attribute_map = {
            'action': 'action'
        }

        self._action = None

    @staticmethod
    def get_subtype(object_dictionary):
        """
        Given the hash representation of a subtype of this class,
        use the info in the hash to return the class of the subtype.
        """
        type = object_dictionary['action']

        if type == 'ADD_HTTP_REQUEST_HEADER':
            return 'AddHttpRequestHeaderRule'

        if type == 'REDIRECT':
            return 'RedirectRule'

        if type == 'REMOVE_HTTP_REQUEST_HEADER':
            return 'RemoveHttpRequestHeaderRule'

        if type == 'EXTEND_HTTP_REQUEST_HEADER_VALUE':
            return 'ExtendHttpRequestHeaderValueRule'

        if type == 'REMOVE_HTTP_RESPONSE_HEADER':
            return 'RemoveHttpResponseHeaderRule'

        if type == 'CONTROL_ACCESS_USING_HTTP_METHODS':
            return 'ControlAccessUsingHttpMethodsRule'

        if type == 'ALLOW':
            return 'AllowRule'

        if type == 'HTTP_HEADER':
            return 'HttpHeaderRule'

        if type == 'ADD_HTTP_RESPONSE_HEADER':
            return 'AddHttpResponseHeaderRule'

        if type == 'EXTEND_HTTP_RESPONSE_HEADER_VALUE':
            return 'ExtendHttpResponseHeaderValueRule'
        else:
            return 'Rule'

    @property
    def action(self):
        """
        **[Required]** Gets the action of this Rule.
        Allowed values for this property are: "ADD_HTTP_REQUEST_HEADER", "EXTEND_HTTP_REQUEST_HEADER_VALUE", "REMOVE_HTTP_REQUEST_HEADER", "ADD_HTTP_RESPONSE_HEADER", "EXTEND_HTTP_RESPONSE_HEADER_VALUE", "REMOVE_HTTP_RESPONSE_HEADER", "ALLOW", "CONTROL_ACCESS_USING_HTTP_METHODS", "REDIRECT", "HTTP_HEADER", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The action of this Rule.
        :rtype: str
        """
        return self._action

    @action.setter
    def action(self, action):
        """
        Sets the action of this Rule.

        :param action: The action of this Rule.
        :type: str
        """
        allowed_values = ["ADD_HTTP_REQUEST_HEADER", "EXTEND_HTTP_REQUEST_HEADER_VALUE", "REMOVE_HTTP_REQUEST_HEADER", "ADD_HTTP_RESPONSE_HEADER", "EXTEND_HTTP_RESPONSE_HEADER_VALUE", "REMOVE_HTTP_RESPONSE_HEADER", "ALLOW", "CONTROL_ACCESS_USING_HTTP_METHODS", "REDIRECT", "HTTP_HEADER"]
        if not value_allowed_none_or_none_sentinel(action, allowed_values):
            action = 'UNKNOWN_ENUM_VALUE'
        self._action = action

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class QueryResultResponse(object):
    """
    A response containing a collection of query rows (selected attributes and aggregations) filtered, grouped and
    sorted by the specified criteria from the query that is run, and the associated summary describing the corresponding
    query result metadata.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new QueryResultResponse object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param query_result_metadata_summary:
            The value to assign to the query_result_metadata_summary property of this QueryResultResponse.
        :type query_result_metadata_summary: oci.apm_traces.models.QueryResultMetadataSummary

        :param query_result_rows:
            The value to assign to the query_result_rows property of this QueryResultResponse.
        :type query_result_rows: list[oci.apm_traces.models.QueryResultRow]

        """
        self.swagger_types = {
            'query_result_metadata_summary': 'QueryResultMetadataSummary',
            'query_result_rows': 'list[QueryResultRow]'
        }

        self.attribute_map = {
            'query_result_metadata_summary': 'queryResultMetadataSummary',
            'query_result_rows': 'queryResultRows'
        }

        self._query_result_metadata_summary = None
        self._query_result_rows = None

    @property
    def query_result_metadata_summary(self):
        """
        **[Required]** Gets the query_result_metadata_summary of this QueryResultResponse.

        :return: The query_result_metadata_summary of this QueryResultResponse.
        :rtype: oci.apm_traces.models.QueryResultMetadataSummary
        """
        return self._query_result_metadata_summary

    @query_result_metadata_summary.setter
    def query_result_metadata_summary(self, query_result_metadata_summary):
        """
        Sets the query_result_metadata_summary of this QueryResultResponse.

        :param query_result_metadata_summary: The query_result_metadata_summary of this QueryResultResponse.
        :type: oci.apm_traces.models.QueryResultMetadataSummary
        """
        self._query_result_metadata_summary = query_result_metadata_summary

    @property
    def query_result_rows(self):
        """
        **[Required]** Gets the query_result_rows of this QueryResultResponse.
        A collection of objects with each object representing an individual row of the query result set.  The total number of objects
        returned in this collection correspond to the total number of rows returned by the actual query that is run against
        the queried entity.


        :return: The query_result_rows of this QueryResultResponse.
        :rtype: list[oci.apm_traces.models.QueryResultRow]
        """
        return self._query_result_rows

    @query_result_rows.setter
    def query_result_rows(self, query_result_rows):
        """
        Sets the query_result_rows of this QueryResultResponse.
        A collection of objects with each object representing an individual row of the query result set.  The total number of objects
        returned in this collection correspond to the total number of rows returned by the actual query that is run against
        the queried entity.


        :param query_result_rows: The query_result_rows of this QueryResultResponse.
        :type: list[oci.apm_traces.models.QueryResultRow]
        """
        self._query_result_rows = query_result_rows

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class MountTargetSummary(object):
    """
    Summary information for the specified mount target.
    """

    #: A constant which can be used with the lifecycle_state property of a MountTargetSummary.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a MountTargetSummary.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a MountTargetSummary.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a MountTargetSummary.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    #: A constant which can be used with the lifecycle_state property of a MountTargetSummary.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    def __init__(self, **kwargs):
        """
        Initializes a new MountTargetSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param availability_domain:
            The value to assign to the availability_domain property of this MountTargetSummary.
        :type availability_domain: str

        :param compartment_id:
            The value to assign to the compartment_id property of this MountTargetSummary.
        :type compartment_id: str

        :param display_name:
            The value to assign to the display_name property of this MountTargetSummary.
        :type display_name: str

        :param export_set_id:
            The value to assign to the export_set_id property of this MountTargetSummary.
        :type export_set_id: str

        :param id:
            The value to assign to the id property of this MountTargetSummary.
        :type id: str

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this MountTargetSummary.
            Allowed values for this property are: "CREATING", "ACTIVE", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param private_ip_ids:
            The value to assign to the private_ip_ids property of this MountTargetSummary.
        :type private_ip_ids: list[str]

        :param subnet_id:
            The value to assign to the subnet_id property of this MountTargetSummary.
        :type subnet_id: str

        :param nsg_ids:
            The value to assign to the nsg_ids property of this MountTargetSummary.
        :type nsg_ids: list[str]

        :param time_created:
            The value to assign to the time_created property of this MountTargetSummary.
        :type time_created: datetime

        :param freeform_tags:
            The value to assign to the freeform_tags property of this MountTargetSummary.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this MountTargetSummary.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'availability_domain': 'str',
            'compartment_id': 'str',
            'display_name': 'str',
            'export_set_id': 'str',
            'id': 'str',
            'lifecycle_state': 'str',
            'private_ip_ids': 'list[str]',
            'subnet_id': 'str',
            'nsg_ids': 'list[str]',
            'time_created': 'datetime',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'availability_domain': 'availabilityDomain',
            'compartment_id': 'compartmentId',
            'display_name': 'displayName',
            'export_set_id': 'exportSetId',
            'id': 'id',
            'lifecycle_state': 'lifecycleState',
            'private_ip_ids': 'privateIpIds',
            'subnet_id': 'subnetId',
            'nsg_ids': 'nsgIds',
            'time_created': 'timeCreated',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._availability_domain = None
        self._compartment_id = None
        self._display_name = None
        self._export_set_id = None
        self._id = None
        self._lifecycle_state = None
        self._private_ip_ids = None
        self._subnet_id = None
        self._nsg_ids = None
        self._time_created = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def availability_domain(self):
        """
        Gets the availability_domain of this MountTargetSummary.
        The availability domain the mount target is in. May be unset
        as a blank or NULL value.

        Example: `Uocm:PHX-AD-1`


        :return: The availability_domain of this MountTargetSummary.
        :rtype: str
        """
        return self._availability_domain

    @availability_domain.setter
    def availability_domain(self, availability_domain):
        """
        Sets the availability_domain of this MountTargetSummary.
        The availability domain the mount target is in. May be unset
        as a blank or NULL value.

        Example: `Uocm:PHX-AD-1`


        :param availability_domain: The availability_domain of this MountTargetSummary.
        :type: str
        """
        self._availability_domain = availability_domain

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this MountTargetSummary.
        The `OCID`__ of the compartment that contains the mount target.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this MountTargetSummary.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this MountTargetSummary.
        The `OCID`__ of the compartment that contains the mount target.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this MountTargetSummary.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this MountTargetSummary.
        A user-friendly name. It does not have to be unique, and it is changeable.
        Avoid entering confidential information.

        Example: `My mount target`


        :return: The display_name of this MountTargetSummary.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this MountTargetSummary.
        A user-friendly name. It does not have to be unique, and it is changeable.
        Avoid entering confidential information.

        Example: `My mount target`


        :param display_name: The display_name of this MountTargetSummary.
        :type: str
        """
        self._display_name = display_name

    @property
    def export_set_id(self):
        """
        Gets the export_set_id of this MountTargetSummary.
        The `OCID`__ of the associated export set. Controls what file
        systems will be exported using Network File System (NFS) protocol on
        this mount target.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The export_set_id of this MountTargetSummary.
        :rtype: str
        """
        return self._export_set_id

    @export_set_id.setter
    def export_set_id(self, export_set_id):
        """
        Sets the export_set_id of this MountTargetSummary.
        The `OCID`__ of the associated export set. Controls what file
        systems will be exported using Network File System (NFS) protocol on
        this mount target.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param export_set_id: The export_set_id of this MountTargetSummary.
        :type: str
        """
        self._export_set_id = export_set_id

    @property
    def id(self):
        """
        **[Required]** Gets the id of this MountTargetSummary.
        The `OCID`__ of the mount target.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The id of this MountTargetSummary.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this MountTargetSummary.
        The `OCID`__ of the mount target.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param id: The id of this MountTargetSummary.
        :type: str
        """
        self._id = id

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this MountTargetSummary.
        The current state of the mount target.

        Allowed values for this property are: "CREATING", "ACTIVE", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this MountTargetSummary.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this MountTargetSummary.
        The current state of the mount target.


        :param lifecycle_state: The lifecycle_state of this MountTargetSummary.
        :type: str
        """
        allowed_values = ["CREATING", "ACTIVE", "DELETING", "DELETED", "FAILED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def private_ip_ids(self):
        """
        **[Required]** Gets the private_ip_ids of this MountTargetSummary.
        The OCIDs of the private IP addresses associated with this mount target.


        :return: The private_ip_ids of this MountTargetSummary.
        :rtype: list[str]
        """
        return self._private_ip_ids

    @private_ip_ids.setter
    def private_ip_ids(self, private_ip_ids):
        """
        Sets the private_ip_ids of this MountTargetSummary.
        The OCIDs of the private IP addresses associated with this mount target.


        :param private_ip_ids: The private_ip_ids of this MountTargetSummary.
        :type: list[str]
        """
        self._private_ip_ids = private_ip_ids

    @property
    def subnet_id(self):
        """
        **[Required]** Gets the subnet_id of this MountTargetSummary.
        The `OCID`__ of the subnet the mount target is in.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The subnet_id of this MountTargetSummary.
        :rtype: str
        """
        return self._subnet_id

    @subnet_id.setter
    def subnet_id(self, subnet_id):
        """
        Sets the subnet_id of this MountTargetSummary.
        The `OCID`__ of the subnet the mount target is in.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param subnet_id: The subnet_id of this MountTargetSummary.
        :type: str
        """
        self._subnet_id = subnet_id

    @property
    def nsg_ids(self):
        """
        Gets the nsg_ids of this MountTargetSummary.
        A list of Network Security Group `OCIDs`__ associated with this mount target.
        A maximum of 5 is allowed.
        Setting this to an empty array after the list is created removes the mount target from all NSGs.
        For more information about NSGs, see `Security Rules`__.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm
        __ https://docs.cloud.oracle.com/Content/Network/Concepts/securityrules.htm


        :return: The nsg_ids of this MountTargetSummary.
        :rtype: list[str]
        """
        return self._nsg_ids

    @nsg_ids.setter
    def nsg_ids(self, nsg_ids):
        """
        Sets the nsg_ids of this MountTargetSummary.
        A list of Network Security Group `OCIDs`__ associated with this mount target.
        A maximum of 5 is allowed.
        Setting this to an empty array after the list is created removes the mount target from all NSGs.
        For more information about NSGs, see `Security Rules`__.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm
        __ https://docs.cloud.oracle.com/Content/Network/Concepts/securityrules.htm


        :param nsg_ids: The nsg_ids of this MountTargetSummary.
        :type: list[str]
        """
        self._nsg_ids = nsg_ids

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this MountTargetSummary.
        The date and time the mount target was created, expressed
        in `RFC 3339`__ timestamp format.

        Example: `2016-08-25T21:10:29.600Z`

        __ https://tools.ietf.org/rfc/rfc3339


        :return: The time_created of this MountTargetSummary.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this MountTargetSummary.
        The date and time the mount target was created, expressed
        in `RFC 3339`__ timestamp format.

        Example: `2016-08-25T21:10:29.600Z`

        __ https://tools.ietf.org/rfc/rfc3339


        :param time_created: The time_created of this MountTargetSummary.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this MountTargetSummary.
        Free-form tags for this resource. Each tag is a simple key-value pair
         with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this MountTargetSummary.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this MountTargetSummary.
        Free-form tags for this resource. Each tag is a simple key-value pair
         with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this MountTargetSummary.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this MountTargetSummary.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this MountTargetSummary.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this MountTargetSummary.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this MountTargetSummary.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .host_configuration_metric_group import HostConfigurationMetricGroup
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class HostProduct(HostConfigurationMetricGroup):
    """
    Product metric for the host
    """

    def __init__(self, **kwargs):
        """
        Initializes a new HostProduct object with values from keyword arguments. The default value of the :py:attr:`~oci.opsi.models.HostProduct.metric_name` attribute
        of this class is ``HOST_PRODUCT`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param metric_name:
            The value to assign to the metric_name property of this HostProduct.
            Allowed values for this property are: "HOST_PRODUCT", "HOST_RESOURCE_ALLOCATION", "HOST_MEMORY_CONFIGURATION", "HOST_HARDWARE_CONFIGURATION", "HOST_CPU_HARDWARE_CONFIGURATION", "HOST_NETWORK_CONFIGURATION", "HOST_ENTITES"
        :type metric_name: str

        :param time_collected:
            The value to assign to the time_collected property of this HostProduct.
        :type time_collected: datetime

        :param vendor:
            The value to assign to the vendor property of this HostProduct.
        :type vendor: str

        :param name:
            The value to assign to the name property of this HostProduct.
        :type name: str

        :param version:
            The value to assign to the version property of this HostProduct.
        :type version: str

        """
        self.swagger_types = {
            'metric_name': 'str',
            'time_collected': 'datetime',
            'vendor': 'str',
            'name': 'str',
            'version': 'str'
        }

        self.attribute_map = {
            'metric_name': 'metricName',
            'time_collected': 'timeCollected',
            'vendor': 'vendor',
            'name': 'name',
            'version': 'version'
        }

        self._metric_name = None
        self._time_collected = None
        self._vendor = None
        self._name = None
        self._version = None
        self._metric_name = 'HOST_PRODUCT'

    @property
    def vendor(self):
        """
        Gets the vendor of this HostProduct.
        Vendor of the product


        :return: The vendor of this HostProduct.
        :rtype: str
        """
        return self._vendor

    @vendor.setter
    def vendor(self, vendor):
        """
        Sets the vendor of this HostProduct.
        Vendor of the product


        :param vendor: The vendor of this HostProduct.
        :type: str
        """
        self._vendor = vendor

    @property
    def name(self):
        """
        Gets the name of this HostProduct.
        Name of the product


        :return: The name of this HostProduct.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this HostProduct.
        Name of the product


        :param name: The name of this HostProduct.
        :type: str
        """
        self._name = name

    @property
    def version(self):
        """
        Gets the version of this HostProduct.
        Version of the product


        :return: The version of this HostProduct.
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this HostProduct.
        Version of the product


        :param version: The version of this HostProduct.
        :type: str
        """
        self._version = version

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class SteeringPolicyLimitRuleCase(object):
    """
    SteeringPolicyLimitRuleCase model.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new SteeringPolicyLimitRuleCase object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param case_condition:
            The value to assign to the case_condition property of this SteeringPolicyLimitRuleCase.
        :type case_condition: str

        :param count:
            The value to assign to the count property of this SteeringPolicyLimitRuleCase.
        :type count: int

        """
        self.swagger_types = {
            'case_condition': 'str',
            'count': 'int'
        }

        self.attribute_map = {
            'case_condition': 'caseCondition',
            'count': 'count'
        }

        self._case_condition = None
        self._count = None

    @property
    def case_condition(self):
        """
        Gets the case_condition of this SteeringPolicyLimitRuleCase.
        An expression that uses conditions at the time of a DNS query to indicate
        whether a case matches. Conditions may include the geographical location, IP
        subnet, or ASN the DNS query originated. **Example:** If you have an
        office that uses the subnet `192.0.2.0/24` you could use a `caseCondition`
        expression `query.client.subnet in ('192.0.2.0/24')` to define a case that
        matches queries from that office.


        :return: The case_condition of this SteeringPolicyLimitRuleCase.
        :rtype: str
        """
        return self._case_condition

    @case_condition.setter
    def case_condition(self, case_condition):
        """
        Sets the case_condition of this SteeringPolicyLimitRuleCase.
        An expression that uses conditions at the time of a DNS query to indicate
        whether a case matches. Conditions may include the geographical location, IP
        subnet, or ASN the DNS query originated. **Example:** If you have an
        office that uses the subnet `192.0.2.0/24` you could use a `caseCondition`
        expression `query.client.subnet in ('192.0.2.0/24')` to define a case that
        matches queries from that office.


        :param case_condition: The case_condition of this SteeringPolicyLimitRuleCase.
        :type: str
        """
        self._case_condition = case_condition

    @property
    def count(self):
        """
        **[Required]** Gets the count of this SteeringPolicyLimitRuleCase.
        The number of answers allowed to remain after the limit rule has been processed, keeping only the
        first of the remaining answers in the list. Example: If the `count` property is set to `2` and
        four answers remain before the limit rule is processed, only the first two answers in the list will
        remain after the limit rule has been processed.


        :return: The count of this SteeringPolicyLimitRuleCase.
        :rtype: int
        """
        return self._count

    @count.setter
    def count(self, count):
        """
        Sets the count of this SteeringPolicyLimitRuleCase.
        The number of answers allowed to remain after the limit rule has been processed, keeping only the
        first of the remaining answers in the list. Example: If the `count` property is set to `2` and
        four answers remain before the limit rule is processed, only the first two answers in the list will
        remain after the limit rule has been processed.


        :param count: The count of this SteeringPolicyLimitRuleCase.
        :type: int
        """
        self._count = count

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class SavedCustomTable(object):
    """
    The custom table for Cost Analysis UI rendering.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new SavedCustomTable object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param display_name:
            The value to assign to the display_name property of this SavedCustomTable.
        :type display_name: str

        :param row_group_by:
            The value to assign to the row_group_by property of this SavedCustomTable.
        :type row_group_by: list[str]

        :param column_group_by:
            The value to assign to the column_group_by property of this SavedCustomTable.
        :type column_group_by: list[str]

        :param group_by_tag:
            The value to assign to the group_by_tag property of this SavedCustomTable.
        :type group_by_tag: list[oci.usage_api.models.Tag]

        :param compartment_depth:
            The value to assign to the compartment_depth property of this SavedCustomTable.
        :type compartment_depth: float

        :param version:
            The value to assign to the version property of this SavedCustomTable.
        :type version: float

        """
        self.swagger_types = {
            'display_name': 'str',
            'row_group_by': 'list[str]',
            'column_group_by': 'list[str]',
            'group_by_tag': 'list[Tag]',
            'compartment_depth': 'float',
            'version': 'float'
        }

        self.attribute_map = {
            'display_name': 'displayName',
            'row_group_by': 'rowGroupBy',
            'column_group_by': 'columnGroupBy',
            'group_by_tag': 'groupByTag',
            'compartment_depth': 'compartmentDepth',
            'version': 'version'
        }

        self._display_name = None
        self._row_group_by = None
        self._column_group_by = None
        self._group_by_tag = None
        self._compartment_depth = None
        self._version = None

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this SavedCustomTable.
        The name of the custom table.


        :return: The display_name of this SavedCustomTable.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this SavedCustomTable.
        The name of the custom table.


        :param display_name: The display_name of this SavedCustomTable.
        :type: str
        """
        self._display_name = display_name

    @property
    def row_group_by(self):
        """
        Gets the row_group_by of this SavedCustomTable.
        The row groupBy key list.
        example:
          `[\"tagNamespace\", \"tagKey\", \"tagValue\", \"service\", \"skuName\", \"skuPartNumber\", \"unit\",
            \"compartmentName\", \"compartmentPath\", \"compartmentId\", \"platform\", \"region\", \"logicalAd\",
            \"resourceId\", \"tenantId\", \"tenantName\"]`


        :return: The row_group_by of this SavedCustomTable.
        :rtype: list[str]
        """
        return self._row_group_by

    @row_group_by.setter
    def row_group_by(self, row_group_by):
        """
        Sets the row_group_by of this SavedCustomTable.
        The row groupBy key list.
        example:
          `[\"tagNamespace\", \"tagKey\", \"tagValue\", \"service\", \"skuName\", \"skuPartNumber\", \"unit\",
            \"compartmentName\", \"compartmentPath\", \"compartmentId\", \"platform\", \"region\", \"logicalAd\",
            \"resourceId\", \"tenantId\", \"tenantName\"]`


        :param row_group_by: The row_group_by of this SavedCustomTable.
        :type: list[str]
        """
        self._row_group_by = row_group_by

    @property
    def column_group_by(self):
        """
        Gets the column_group_by of this SavedCustomTable.
        The column groupBy key list.
        example:
          `[\"tagNamespace\", \"tagKey\", \"tagValue\", \"service\", \"skuName\", \"skuPartNumber\", \"unit\",
            \"compartmentName\", \"compartmentPath\", \"compartmentId\", \"platform\", \"region\", \"logicalAd\",
            \"resourceId\", \"tenantId\", \"tenantName\"]`


        :return: The column_group_by of this SavedCustomTable.
        :rtype: list[str]
        """
        return self._column_group_by

    @column_group_by.setter
    def column_group_by(self, column_group_by):
        """
        Sets the column_group_by of this SavedCustomTable.
        The column groupBy key list.
        example:
          `[\"tagNamespace\", \"tagKey\", \"tagValue\", \"service\", \"skuName\", \"skuPartNumber\", \"unit\",
            \"compartmentName\", \"compartmentPath\", \"compartmentId\", \"platform\", \"region\", \"logicalAd\",
            \"resourceId\", \"tenantId\", \"tenantName\"]`


        :param column_group_by: The column_group_by of this SavedCustomTable.
        :type: list[str]
        """
        self._column_group_by = column_group_by

    @property
    def group_by_tag(self):
        """
        Gets the group_by_tag of this SavedCustomTable.
        GroupBy a specific tagKey. Provide the tagNamespace and tagKey in the tag object. Only one tag in the list is supported.
        For example:
          `[{\"namespace\":\"oracle\", \"key\":\"createdBy\"]`


        :return: The group_by_tag of this SavedCustomTable.
        :rtype: list[oci.usage_api.models.Tag]
        """
        return self._group_by_tag

    @group_by_tag.setter
    def group_by_tag(self, group_by_tag):
        """
        Sets the group_by_tag of this SavedCustomTable.
        GroupBy a specific tagKey. Provide the tagNamespace and tagKey in the tag object. Only one tag in the list is supported.
        For example:
          `[{\"namespace\":\"oracle\", \"key\":\"createdBy\"]`


        :param group_by_tag: The group_by_tag of this SavedCustomTable.
        :type: list[oci.usage_api.models.Tag]
        """
        self._group_by_tag = group_by_tag

    @property
    def compartment_depth(self):
        """
        Gets the compartment_depth of this SavedCustomTable.
        The compartment depth level.


        :return: The compartment_depth of this SavedCustomTable.
        :rtype: float
        """
        return self._compartment_depth

    @compartment_depth.setter
    def compartment_depth(self, compartment_depth):
        """
        Sets the compartment_depth of this SavedCustomTable.
        The compartment depth level.


        :param compartment_depth: The compartment_depth of this SavedCustomTable.
        :type: float
        """
        self._compartment_depth = compartment_depth

    @property
    def version(self):
        """
        Gets the version of this SavedCustomTable.
        The version of the custom table.


        :return: The version of this SavedCustomTable.
        :rtype: float
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this SavedCustomTable.
        The version of the custom table.


        :param version: The version of this SavedCustomTable.
        :type: float
        """
        self._version = version

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
